# ff-admin-server

Administration für Feuerwehren und Vereine (Backend).

## Einleitung

Dieses Projekt, `ff-admin-server`, ist das Backend zur Verwaltung von Mitgliederdaten. Die zugehörige Webapp ist im Repository [ff-admin-ui](https://forgejo.jk-effects.cloud/Ehrenamt/ff-admin) zu finden.

Eine Demo zusammen mit der `ff-admin` finden Sie unter [https://admin-demo.ff-admin.de](https://admin-demo.ff-admin.de).

Das Handbuch zur Anwendung finden sie unter [https://ff-admin.de/ff-admin-handbook](https://ff-admin.de/ff-admin-handbook).

## Installation

Das Image exposed nur den Port 5000. Die Env-Variable SERVER_PORT kann nur im lokal ausführenden dev-Kontext verwendet werden.

### Docker Compose Setup

Um den Container hochzufahren, erstellen Sie eine `docker-compose.yml` Datei mit folgendem Inhalt:

```yaml
version: "3"

services:
  ff-admin-server:
    image: docker.registry.jk-effects.cloud/ehrenamt/ff-admin/server:latest
    container_name: ff_member_administration_server
    restart: unless-stopped
    environment:
      - DB_TYPE=<mysql|postgres> # default ist auf mysql gesetzt
      - DB_HOST=ff-db
      - DB_PORT=<number> # default ist auf 3306 gesetzt
      - DB_NAME=ffadmin
      - DB_USERNAME=administration_backend
      - DB_PASSWORD=<dbuserpasswd>
      - APPLICATION_SECRET=<tobemodified>
      - USE_SECURITY_STRICT_LIMIT = (true|false) # default ist true
      - SECURITY_STRICT_LIMIT_WINDOW = [0-9]*(y|d|h|m|s) # default ist 15
      - SECURITY_STRICT_LIMIT_REQUEST_COUNT = strict_request_count # default ist 15
      - USE_SECURITY_LIMIT = (true|false) # default ist true
      - SECURITY_LIMIT_WINDOW = [0-9]*(y|d|h|m|s) # default ist 1m
      - SECURITY_LIMIT_REQUEST_COUNT = request_count # default ist 500
      - TRUST_PROXY = <boolean|number|ip|ip1,ip2,...> # wenn leer, wird dieser Wert nicht angewendet.
    volumes:
      - <volume|local path>:/app/files
    networks:
      - ff_internal
    depends_on:
      - ff-db

  ff-db:
    image: mariadb:11.2
    container_name: ff_db
    restart: unless-stopped
    environment:
      - MYSQL_DATABASE=ffadmin
      - MYSQL_USER=administration_backend
      - MYSQL_PASSWORD=<dbuserpasswd>
      - MYSQL_ROOT_PASSWORD=<dbrootpasswd>
    volumes:
      - <volume|local path>:/var/lib/mysql
    networks:
      - ff_internal
  # OR
    image: postgres:16
    container_name: ff_db
    restart: unless-stopped
    environment:   
      - POSTGRES_DB=ffadmin
      - POSTGRES_USER=administration_backend
      - POSTGRES_PASSWORD=<dbuserpasswd>
    volumes:
      - <volume|local path>:/var/lib/postgresql/data
    networks:
      - ff_internal

networks:
  ff_internal:
```

Die Verwendung von postgres wird aufgrund des Verhaltens bei Datenbank-Update-Fehlern empfohlen.

Führen Sie dann den folgenden Befehl im Verzeichnis der compose-Datei aus, um den Container zu starten:

```sh
docker-compose up -d
```

### Manuelle Installation

Klonen Sie dieses Repository und installieren Sie die Abhängigkeiten:

```sh
git clone https://forgejo.jk-effects.cloud/Ehrenamt/ff-admin-server.git
cd ff-admin-server
npm install
npm run build
npm run start
```

## Fragen und Wünsche

Bei Fragen, Anregungen oder Wünschen können Sie sich gerne melden.\
Wir freuen uns über Ihr Feedback und helfen Ihnen gerne weiter.\
Schreiben Sie dafür eine Mail an julian.krauser@jk-effects.com.
