import { dataSource } from "../../../data-source";
import { award } from "../../../entity/configuration/award";
import DatabaseActionException from "../../../exceptions/databaseActionException";
import InternalException from "../../../exceptions/internalException";
import { CreateAwardCommand, DeleteAwardCommand, UpdateAwardCommand } from "./awardCommand";

export default abstract class AwardCommandHandler {
  /**
   * @description create award
   * @param {CreateAwardCommand} createAward
   * @returns {Promise<number>}
   */
  static async create(createAward: CreateAwardCommand): Promise<number> {
    return await dataSource
      .createQueryBuilder()
      .insert()
      .into(award)
      .values({
        award: createAward.award,
      })
      .execute()
      .then((result) => {
        return result.identifiers[0].id;
      })
      .catch((err) => {
        throw new DatabaseActionException("CREATE", "award", err);
      });
  }

  /**
   * @description update award
   * @param {UpdateAwardCommand} updateAward
   * @returns {Promise<void>}
   */
  static async update(updateAward: UpdateAwardCommand): Promise<void> {
    return await dataSource
      .createQueryBuilder()
      .update(award)
      .set({
        award: updateAward.award,
      })
      .where("id = :id", { id: updateAward.id })
      .execute()
      .then(() => {})
      .catch((err) => {
        throw new DatabaseActionException("UPDATE", "award", err);
      });
  }

  /**
   * @description delete award
   * @param {DeleteAwardCommand} deleteAward
   * @returns {Promise<void>}
   */
  static async delete(deleteAward: DeleteAwardCommand): Promise<void> {
    return await dataSource
      .createQueryBuilder()
      .delete()
      .from(award)
      .where("id = :id", { id: deleteAward.id })
      .execute()
      .then(() => {})
      .catch((err) => {
        throw new DatabaseActionException("DELETE", "award", err);
      });
  }
}
