import { dataSource } from "../../../data-source";
import { setting } from "../../../entity/management/setting";
import DatabaseActionException from "../../../exceptions/databaseActionException";
import { CreateOrUpdateSettingCommand, DeleteSettingCommand } from "./settingCommand";

export default abstract class SettingCommandHandler {
  /**
   * @description create setting
   * @param {CreateOrUpdateSettingCommand} createSetting
   * @returns {Promise<string>}
   */
  static async create(createSetting: CreateOrUpdateSettingCommand): Promise<string> {
    return await dataSource
      .createQueryBuilder()
      .insert()
      .into(setting)
      .values({
        topic: createSetting.topic,
        key: createSetting.key,
        value: createSetting.value,
      })
      .orUpdate(["value"], ["topic", "key"])
      .execute()
      .then((result) => {
        return createSetting.value;
      })
      .catch((err) => {
        throw new DatabaseActionException("CREATE OR UPDATE", "setting", err);
      });
  }

  /**
   * @description delete setting by topic and key
   * @param {DeleteRefreshCommand} deleteSetting
   * @returns {Promise<any>}
   */
  static async delete(deleteSetting: DeleteSettingCommand): Promise<any> {
    return await dataSource
      .createQueryBuilder()
      .delete()
      .from(setting)
      .where("setting.topic = :topic", { topic: deleteSetting.topic })
      .andWhere("setting.key = :key", { key: deleteSetting.key })
      .execute()
      .then((res) => {})
      .catch((err) => {
        throw new DatabaseActionException("DELETE", "setting", err);
      });
  }
}
