import { dataSource } from "../../../data-source";
import { equipmentType } from "../../../entity/unit/equipment/equipmentType";
import DatabaseActionException from "../../../exceptions/databaseActionException";
import {
  CreateEquipmentTypeCommand,
  UpdateEquipmentTypeCommand,
  DeleteEquipmentTypeCommand,
} from "./equipmentTypeCommand";

export default abstract class EquipmentTypeCommandHandler {
  /**
   * @description create equipmentType
   * @param {CreateEquipmentTypeCommand} createEquipmentType
   * @returns {Promise<number>}
   */
  static async create(createEquipmentType: CreateEquipmentTypeCommand): Promise<number> {
    return await dataSource
      .createQueryBuilder()
      .insert()
      .into(equipmentType)
      .values({
        type: createEquipmentType.type,
        description: createEquipmentType.description,
      })
      .execute()
      .then((result) => {
        return result.identifiers[0].id;
      })
      .catch((err) => {
        throw new DatabaseActionException("CREATE", "equipmentType", err);
      });
  }

  /**
   * @description update equipmentType
   * @param {UpdateEquipmentTypeCommand} updateEquipmentType
   * @returns {Promise<void>}
   */
  static async update(updateEquipmentType: UpdateEquipmentTypeCommand): Promise<void> {
    return await dataSource
      .createQueryBuilder()
      .update(equipmentType)
      .set({
        type: updateEquipmentType.type,
        description: updateEquipmentType.description,
      })
      .where("id = :id", { id: updateEquipmentType.id })
      .execute()
      .then(() => {})
      .catch((err) => {
        throw new DatabaseActionException("UPDATE", "equipmentType", err);
      });
  }

  /**
   * @description delete equipmentType
   * @param {DeleteEquipmentTypeCommand} deleteEquipmentType
   * @returns {Promise<void>}
   */
  static async delete(deleteEquipmentType: DeleteEquipmentTypeCommand): Promise<void> {
    return await dataSource
      .createQueryBuilder()
      .delete()
      .from(equipmentType)
      .where("id = :id", { id: deleteEquipmentType.id })
      .execute()
      .then(() => {})
      .catch((err) => {
        throw new DatabaseActionException("DELETE", "equipmentType", err);
      });
  }
}
