import { dataSource } from "../../../data-source";
import { inspectionPlan } from "../../../entity/unit/inspection/inspectionPlan";
import DatabaseActionException from "../../../exceptions/databaseActionException";
import {
  CreateInspectionPlanCommand,
  UpdateInspectionPlanCommand,
  DeleteInspectionPlanCommand,
} from "./inspectionPlanCommand";

export default abstract class InspectionPlanCommandHandler {
  /**
   * @description create inspectionPlan
   * @param {CreateInspectionPlanCommand} createInspectionPlan
   * @returns {Promise<number>}
   */
  static async create(createInspectionPlan: CreateInspectionPlanCommand): Promise<number> {
    return await dataSource
      .createQueryBuilder()
      .insert()
      .into(inspectionPlan)
      .values({
        title: createInspectionPlan.title,
        inspectionInterval: createInspectionPlan.inspectionInterval,
        remindTime: createInspectionPlan.remindTime,
        equipmentTypeId: createInspectionPlan.assigned == "equipment" ? createInspectionPlan.relatedId : null,
        vehicleTypeId: createInspectionPlan.assigned == "vehicle" ? createInspectionPlan.relatedId : null,
      })
      .execute()
      .then((result) => {
        return result.identifiers[0].id;
      })
      .catch((err) => {
        throw new DatabaseActionException("CREATE", "inspectionPlan", err);
      });
  }

  /**
   * @description update inspectionPlan
   * @param {UpdateInspectionPlanCommand} updateInspectionPlan
   * @returns {Promise<void>}
   */
  static async update(updateInspectionPlan: UpdateInspectionPlanCommand): Promise<void> {
    return await dataSource
      .createQueryBuilder()
      .update(inspectionPlan)
      .set({
        title: updateInspectionPlan.title,
        inspectionInterval: updateInspectionPlan.inspectionInterval,
        remindTime: updateInspectionPlan.remindTime,
      })
      .where("id = :id", { id: updateInspectionPlan.id })
      .execute()
      .then(() => {})
      .catch((err) => {
        throw new DatabaseActionException("UPDATE", "inspectionPlan", err);
      });
  }

  /**
   * @description delete inspectionPlan
   * @param {DeleteInspectionPlanCommand} deleteInspectionPlan
   * @returns {Promise<void>}
   */
  static async delete(deleteInspectionPlan: DeleteInspectionPlanCommand): Promise<void> {
    return await dataSource
      .createQueryBuilder()
      .delete()
      .from(inspectionPlan)
      .where("id = :id", { id: deleteInspectionPlan.id })
      .execute()
      .then(() => {})
      .catch((err) => {
        throw new DatabaseActionException("DELETE", "inspectionPlan", err);
      });
  }
}
