import { dataSource } from "../../../data-source";
import { vehicleType } from "../../../entity/unit/vehicle/vehicleType";
import DatabaseActionException from "../../../exceptions/databaseActionException";
import { CreateVehicleTypeCommand, UpdateVehicleTypeCommand, DeleteVehicleTypeCommand } from "./vehicleTypeCommand";

export default abstract class VehicleTypeCommandHandler {
  /**
   * @description create vehicleType
   * @param {CreateVehicleTypeCommand} createVehicleType
   * @returns {Promise<number>}
   */
  static async create(createVehicleType: CreateVehicleTypeCommand): Promise<number> {
    return await dataSource
      .createQueryBuilder()
      .insert()
      .into(vehicleType)
      .values({
        type: createVehicleType.type,
        description: createVehicleType.description,
      })
      .execute()
      .then((result) => {
        return result.identifiers[0].id;
      })
      .catch((err) => {
        throw new DatabaseActionException("CREATE", "vehicleType", err);
      });
  }

  /**
   * @description update vehicleType
   * @param {UpdateVehicleTypeCommand} updateVehicleType
   * @returns {Promise<void>}
   */
  static async update(updateVehicleType: UpdateVehicleTypeCommand): Promise<void> {
    return await dataSource
      .createQueryBuilder()
      .update(vehicleType)
      .set({
        type: updateVehicleType.type,
        description: updateVehicleType.description,
      })
      .where("id = :id", { id: updateVehicleType.id })
      .execute()
      .then(() => {})
      .catch((err) => {
        throw new DatabaseActionException("UPDATE", "vehicleType", err);
      });
  }

  /**
   * @description delete vehicleType
   * @param {DeleteVehicleTypeCommand} deleteVehicleType
   * @returns {Promise<void>}
   */
  static async delete(deleteVehicleType: DeleteVehicleTypeCommand): Promise<void> {
    return await dataSource
      .createQueryBuilder()
      .delete()
      .from(vehicleType)
      .where("id = :id", { id: deleteVehicleType.id })
      .execute()
      .then(() => {})
      .catch((err) => {
        throw new DatabaseActionException("DELETE", "vehicleType", err);
      });
  }
}
