import { dataSource } from "../../../data-source";
import { wearableType } from "../../../entity/unit/wearable/wearableType";
import DatabaseActionException from "../../../exceptions/databaseActionException";
import { CreateWearableTypeCommand, UpdateWearableTypeCommand, DeleteWearableTypeCommand } from "./wearableTypeCommand";

export default abstract class WearableTypeCommandHandler {
  /**
   * @description create wearableType
   * @param {CreateWearableTypeCommand} createWearableType
   * @returns {Promise<number>}
   */
  static async create(createWearableType: CreateWearableTypeCommand): Promise<number> {
    return await dataSource
      .createQueryBuilder()
      .insert()
      .into(wearableType)
      .values({
        type: createWearableType.type,
        description: createWearableType.description,
      })
      .execute()
      .then((result) => {
        return result.identifiers[0].id;
      })
      .catch((err) => {
        throw new DatabaseActionException("CREATE", "wearableType", err);
      });
  }

  /**
   * @description update wearableType
   * @param {UpdateWearableTypeCommand} updateWearableType
   * @returns {Promise<void>}
   */
  static async update(updateWearableType: UpdateWearableTypeCommand): Promise<void> {
    return await dataSource
      .createQueryBuilder()
      .update(wearableType)
      .set({
        type: updateWearableType.type,
        description: updateWearableType.description,
      })
      .where("id = :id", { id: updateWearableType.id })
      .execute()
      .then(() => {})
      .catch((err) => {
        throw new DatabaseActionException("UPDATE", "wearableType", err);
      });
  }

  /**
   * @description delete wearableType
   * @param {DeleteWearableTypeCommand} deleteWearableType
   * @returns {Promise<void>}
   */
  static async delete(deleteWearableType: DeleteWearableTypeCommand): Promise<void> {
    return await dataSource
      .createQueryBuilder()
      .delete()
      .from(wearableType)
      .where("id = :id", { id: deleteWearableType.id })
      .execute()
      .then(() => {})
      .catch((err) => {
        throw new DatabaseActionException("DELETE", "wearableType", err);
      });
  }
}
