import { Column, CreateDateColumn, Entity, ManyToOne, PrimaryGeneratedColumn } from "typeorm";
import { equipment } from "./equipment/equipment";
import { wearable } from "./wearable/wearable";
import { vehicle } from "./vehicle/vehicle";
import { repair } from "./repair";

@Entity()
export class damageReport {
  @PrimaryGeneratedColumn("uuid")
  id: string;

  @CreateDateColumn()
  reportedAt: Date;

  @Column({ type: "varchar", length: 255 })
  status: string;

  @Column({ type: "boolean", default: false })
  done: boolean;

  @Column({ type: "varchar", length: 255 })
  title: string;

  @Column({ type: "text" })
  description: string;

  @Column({ type: "text" })
  location: string;

  @Column({ type: "text" })
  noteByReporter: string;

  @Column({ type: "text" })
  noteByWorker: string;

  @Column({
    type: "text",
    transformer: {
      from(value: string): Array<string> {
        return (value ?? "").split(",").filter((i) => !!i);
      },
      to(value: Array<string> = []): string {
        return value.join(",");
      },
    },
  })
  images: string[];

  @Column({ type: "varchar", length: 255 })
  reportedBy: string;

  @Column({ nullable: true, default: null })
  equipmentId?: string;

  @Column({ nullable: true, default: null })
  vehicleId?: string;

  @Column({ nullable: true, default: null })
  wearableId?: string;

  @Column({ nullable: true, default: null })
  repairId?: string;

  @ManyToOne(() => equipment, (e) => e.reports, {
    nullable: true,
    onDelete: "CASCADE",
    onUpdate: "RESTRICT",
  })
  equipment?: equipment;

  @ManyToOne(() => vehicle, (v) => v.reports, {
    nullable: true,
    onDelete: "CASCADE",
    onUpdate: "RESTRICT",
  })
  vehicle?: vehicle;

  @ManyToOne(() => wearable, (w) => w.reports, {
    nullable: true,
    onDelete: "CASCADE",
    onUpdate: "RESTRICT",
  })
  wearable?: wearable;

  @ManyToOne(() => repair, (m) => m.reports, {
    nullable: true,
    onDelete: "SET NULL",
    onUpdate: "RESTRICT",
  })
  repair?: repair;
}
