import { Column, ColumnType, CreateDateColumn, Entity, ManyToOne, OneToMany, PrimaryGeneratedColumn } from "typeorm";
import { equipment } from "./equipment/equipment";
import { wearable } from "./wearable/wearable";
import { vehicle } from "./vehicle/vehicle";
import { damageReport } from "./damageReport";
import { getTypeByORM } from "../../migrations/ormHelper";

@Entity()
export class repair {
  @PrimaryGeneratedColumn("uuid")
  id: string;

  @CreateDateColumn()
  createdAt: Date;

  @Column({ type: getTypeByORM("datetime").type as ColumnType, nullable: true, default: null })
  finishedAt?: Date;

  @Column({ type: "varchar", length: 255 })
  status: string;

  @Column({ type: "varchar", length: 255 })
  responsible: string;

  @Column({ type: "varchar", length: 255 })
  title: string;

  @Column({ type: "text" })
  description: string;

  @Column({
    type: "text",
    transformer: {
      from(value: string): Array<string> {
        return (value ?? "").split(",").filter((i) => !!i);
      },
      to(value: Array<string> = []): string {
        return value.join(",");
      },
    },
  })
  images: string[];

  @Column({ type: "varchar", length: 255, nullable: true, default: null })
  reportDocument?: string;

  @Column({ nullable: true, default: null })
  equipmentId?: string;

  @Column({ nullable: true, default: null })
  vehicleId?: string;

  @Column({ nullable: true, default: null })
  wearableId?: string;

  @ManyToOne(() => equipment, (e) => e.maintenances, {
    nullable: true,
    onDelete: "CASCADE",
    onUpdate: "RESTRICT",
  })
  equipment?: equipment;

  @ManyToOne(() => vehicle, (v) => v.maintenances, {
    nullable: true,
    onDelete: "CASCADE",
    onUpdate: "RESTRICT",
  })
  vehicle?: vehicle;

  @ManyToOne(() => wearable, (w) => w.maintenances, {
    nullable: true,
    onDelete: "CASCADE",
    onUpdate: "RESTRICT",
  })
  wearable?: wearable;

  @OneToMany(() => damageReport, (dr) => dr.repair)
  reports: damageReport[];
}
