import { Column, ColumnType, Entity, ManyToOne, OneToMany, PrimaryGeneratedColumn } from "typeorm";
import { getTypeByORM } from "../../../migrations/ormHelper";
import { wearableType } from "./wearableType";
import { damageReport } from "../damageReport";
import { member } from "../../club/member/member";
import { inspection } from "../inspection/inspection";
import { maintenance } from "../maintenance";
import { repair } from "../repair";

@Entity()
export class wearable {
  @PrimaryGeneratedColumn("uuid")
  id: string;

  @Column({ type: "varchar", length: 255, nullable: true, default: null, unique: true })
  code?: string;

  @Column({ type: "varchar", length: 255 })
  name: string;

  @Column({ type: "varchar", length: 255 })
  location: string;

  @Column({ type: getTypeByORM("date").type as ColumnType })
  commissioned: Date;

  @Column({ type: getTypeByORM("date").type as ColumnType, nullable: true, default: null })
  decommissioned?: Date;

  @Column()
  wearableTypeId: string;

  @Column({ nullable: true, default: null })
  wearerId?: string;

  @ManyToOne(() => wearableType, {
    nullable: false,
    onDelete: "RESTRICT",
    onUpdate: "RESTRICT",
  })
  wearableType: wearableType;

  @ManyToOne(() => member, {
    nullable: true,
    onDelete: "SET NULL",
    onUpdate: "RESTRICT",
  })
  wearer?: member;

  @OneToMany(() => damageReport, (d) => d.wearable, { cascade: ["insert"] })
  reports: damageReport[];

  @OneToMany(() => repair, (d) => d.wearable, { cascade: ["insert"] })
  repairs: repair[];

  @OneToMany(() => maintenance, (m) => m.wearable, { cascade: ["insert"] })
  maintenances: maintenance[];

  @OneToMany(() => inspection, (i) => i.wearable, { cascade: ["insert"] })
  inspections: inspection[];
}
