import { calendar } from "../../../entity/club/calendar";
import { CalendarViewModel } from "../../../viewmodel/admin/club/calendar.models";
import CalendarTypeFactory from "../configuration/calendarType";

export default abstract class CalendarFactory {
  /**
   * @description map record to calendar
   * @param {calendar} record
   * @returns {CalendarViewModel}
   */
  public static mapToSingle(record: calendar): CalendarViewModel {
    return {
      id: record.id,
      starttime: record.starttime,
      endtime: record.endtime,
      title: record.title,
      content: record.content,
      location: record.location,
      allDay: record.allDay,
      createdAt: record.createdAt,
      updatedAt: record.updatedAt,
      type: CalendarTypeFactory.mapToSingle(record.type),
    };
  }

  /**
   * @description map records to calendar
   * @param {Array<calendar>} records
   * @returns {Array<CalendarViewModel>}
   */
  public static mapToBase(records: Array<calendar>): Array<CalendarViewModel> {
    return records.map((r) => this.mapToSingle(r));
  }
}
