import { memberExecutivePositions } from "../../../../entity/club/member/memberExecutivePositions";
import { MemberExecutivePositionViewModel } from "../../../../viewmodel/admin/club/member/memberExecutivePosition.models";

export default abstract class MemberExecutivePositionFactory {
  /**
   * @description map record to memberExecutivePosition
   * @param {memberExecutivePosition} record
   * @returns {MemberExecutivePositionViewModel}
   */
  public static mapToSingle(record: memberExecutivePositions): MemberExecutivePositionViewModel {
    return {
      id: record.id,
      note: record.note,
      start: record.start,
      end: record.end,
      executivePosition: record.executivePosition.position,
      executivePositionId: record.executivePosition.id,
    };
  }

  /**
   * @description map records to memberExecutivePosition
   * @param {Array<memberExecutivePosition>} records
   * @returns {Array<MemberExecutivePositionViewModel>}
   */
  public static mapToBase(records: Array<memberExecutivePositions>): Array<MemberExecutivePositionViewModel> {
    return records.map((r) => this.mapToSingle(r));
  }
}
