import { newsletterDates } from "../../../../entity/club/newsletter/newsletterDates";
import { NewsletterDatesViewModel } from "../../../../viewmodel/admin/club/newsletter/newsletterDates.models";
import CalendarFactory from "../calendar";
import MemberFactory from "../member/member";

export default abstract class NewsletterDatesFactory {
  /**
   * @description map record to newsletterDates
   * @param {newsletterDates} record
   * @returns {NewsletterDatesViewModel}
   */
  public static mapToSingle(record: newsletterDates): NewsletterDatesViewModel {
    return {
      newsletterId: record.newsletterId,
      calendarId: record.calendarId,
      diffTitle: record.diffTitle,
      diffDescription: record.diffDescription,
      calendar: CalendarFactory.mapToSingle(record.calendar),
    };
  }

  /**
   * @description map records to newsletterDates
   * @param {Array<newsletterDates>} records
   * @returns {Array<NewsletterDatesViewModel>}
   */
  public static mapToBase(records: Array<newsletterDates>): Array<NewsletterDatesViewModel> {
    return records.map((r) => this.mapToSingle(r));
  }
}
