import { template } from "../../../entity/configuration/template";
import { TemplateViewModel } from "../../../viewmodel/admin/configuration/template.models";

export default abstract class TemplateFactory {
  /**
   * @description map record to template
   * @param {template} record
   * @returns {TemplateViewModel}
   */
  public static mapToSingle(record: template): TemplateViewModel {
    return {
      id: record.id,
      template: record.template,
      description: record.description,
      design: record.design,
      html: record.html,
    };
  }

  /**
   * @description map records to template
   * @param {Array<template>} records
   * @returns {Array<TemplateViewModel>}
   */
  public static mapToBase(records: Array<template>): Array<TemplateViewModel> {
    return records.map((r) => this.mapToSingle(r));
  }
}
