import { templateUsage } from "../../../entity/configuration/templateUsage";
import { TemplateUsageViewModel } from "../../../viewmodel/admin/configuration/templateUsage.models";

export default abstract class TemplateUsageFactory {
  /**
   * @description map record to templateUsage
   * @param {templateUsage} record
   * @returns {TemplateUsageViewModel}
   */
  public static mapToSingle(record: templateUsage): TemplateUsageViewModel {
    return {
      scope: record.scope,
      header: record.header ? { id: record.header.id, template: record.header.template } : null,
      body: record.body ? { id: record.body.id, template: record.body.template } : null,
      footer: record.footer ? { id: record.footer.id, template: record.footer.template } : null,
      headerHeight: record.headerHeight,
      footerHeight: record.footerHeight,
    };
  }

  /**
   * @description map records to templateUsage
   * @param {Array<templateUsage>} records
   * @returns {Array<TemplateUsageViewModel>}
   */
  public static mapToBase(records: Array<templateUsage>): Array<TemplateUsageViewModel> {
    return records.map((r) => this.mapToSingle(r));
  }
}
