import { role } from "../../../entity/management/role";
import PermissionHelper from "../../../helpers/permissionHelper";
import { RoleViewModel } from "../../../viewmodel/admin/management/role.models";

export default abstract class RoleFactory {
  /**
   * @description map record to role
   * @param {role} record
   * @returns {roleViewModel}
   */
  public static mapToSingle(record: role): RoleViewModel {
    return {
      id: record.id,
      permissions: PermissionHelper.convertToObject(record.permissions.map((e) => e.permission)),
      role: record.role,
    };
  }

  /**
   * @description map records to role
   * @param {Array<role>} records
   * @returns {Array<roleViewModel>}
   */
  public static mapToBase(records: Array<role>): Array<RoleViewModel> {
    return records.map((r) => this.mapToSingle(r));
  }
}
