import { damageReport } from "../../../entity/unit/damageReport";
import { DamageReportAssigned, DamageReportViewModel } from "../../../viewmodel/admin/unit/damageReport.models";
import EquipmentFactory from "./equipment/equipment";
import MaintenanceFactory from "./maintenance";
import RepairFactory from "./repair";
import VehicleFactory from "./vehicle/vehicle";
import WearableFactory from "./wearable/wearable";

export default abstract class DamageReportFactory {
  /**
   * @description map record to damageReport
   * @param {damageReport} record
   * @returns {DamageReportViewModel}
   */
  public static mapToSingle(record: damageReport): DamageReportViewModel {
    let assigned: DamageReportAssigned;
    if (record?.equipmentId) {
      assigned = {
        relatedId: record.equipmentId,
        assigned: "equipment",
        related: record.equipment ? EquipmentFactory.mapToSingle(record.equipment) : undefined,
      };
    } else if (record?.vehicleId) {
      assigned = {
        relatedId: record.vehicleId,
        assigned: "vehicle",
        related: record.vehicle ? VehicleFactory.mapToSingle(record.vehicle) : undefined,
      };
    } else if (record?.wearableId) {
      assigned = {
        relatedId: record.wearableId,
        assigned: "wearable",
        related: record.wearable ? WearableFactory.mapToSingle(record.wearable) : undefined,
      };
    } else {
      assigned = {
        relatedId: undefined,
        assigned: undefined,
        related: undefined,
      };
    }

    return {
      id: record.id,
      reportedAt: record.reportedAt,
      status: record.status,
      done: record.done,
      title: record.title,
      description: record.description,
      location: record.location,
      noteByReporter: record.noteByReporter,
      noteByWorker: record.noteByWorker,
      images: record.images,
      reportedBy: record?.reportedBy,
      ...assigned,
      repair: record.repair ? RepairFactory.mapToSingle(record.repair) : null,
    };
  }

  /**
   * @description map records to damageReport
   * @param {Array<damageReport>} records
   * @returns {Array<DamageReportViewModel>}
   */
  public static mapToBase(records: Array<damageReport>): Array<DamageReportViewModel> {
    return records.map((r) => this.mapToSingle(r));
  }
}
