import { equipmentType } from "../../../../entity/unit/equipment/equipmentType";
import { EquipmentTypeViewModel } from "../../../../viewmodel/admin/unit/equipment/equipmentType.models";

export default abstract class EquipmentTypeFactory {
  /**
   * @description map record to equipmentType
   * @param {equipmentType} record
   * @returns {EquipmentTypeViewModel}
   */
  public static mapToSingle(record: equipmentType): EquipmentTypeViewModel {
    return {
      id: record.id,
      type: record.type,
      description: record.description,
      equipmentCount: record.equipmentCount,
    };
  }

  /**
   * @description map records to equipmentType
   * @param {Array<equipmentType>} records
   * @returns {Array<EquipmentTypeViewModel>}
   */
  public static mapToBase(records: Array<equipmentType>): Array<EquipmentTypeViewModel> {
    return records.map((r) => this.mapToSingle(r));
  }
}
