import { inspectionPoint } from "../../../../entity/unit/inspection/inspectionPoint";
import { InspectionPointViewModel } from "../../../../viewmodel/admin/unit/inspection/inspectionPlan.models";

export default abstract class InspectionPointFactory {
  /**
   * @description map record to inspectionPoint
   * @param {inspectionPoint} record
   * @returns {InspectionPointViewModel}
   */
  public static mapToSingle(record: inspectionPoint): InspectionPointViewModel {
    return {
      id: record.id,
      title: record.title,
      description: record.description,
      type: record.type,
      sort: record.sort,
      min: record?.min,
      max: record?.max,
      others: record?.others,
    };
  }

  /**
   * @description map records to inspectionPoint
   * @param {Array<inspectionPoint>} records
   * @returns {Array<InspectionPointViewModel>}
   */
  public static mapToBase(records: Array<inspectionPoint>): Array<InspectionPointViewModel> {
    return records.map((r) => this.mapToSingle(r));
  }
}
