import { inspectionPointResult } from "../../../../entity/unit/inspection/inspectionPointResult";
import { InspectionPointResultViewModel } from "../../../../viewmodel/admin/unit/inspection/inspection.models";
import InspectionPointFactory from "./inspectionPoint";

export default abstract class InspectionPointResultFactory {
  /**
   * @description map record to inspectionPointResult
   * @param {inspectionPointResult} record
   * @returns {InspectionPointResultViewModel}
   */
  public static mapToSingle(record: inspectionPointResult): InspectionPointResultViewModel {
    return {
      inspectionId: record.inspectionId,
      inspectionPointId: record.inspectionPointId,
      inspectionPoint: InspectionPointFactory.mapToSingle(record.inspectionPoint),
      value: record.value,
    };
  }

  /**
   * @description map records to inspectionPointResult
   * @param {Array<inspectionPointResult>} records
   * @returns {Array<InspectionPointResultViewModel>}
   */
  public static mapToBase(records: Array<inspectionPointResult>): Array<InspectionPointResultViewModel> {
    return records.map((r) => this.mapToSingle(r));
  }
}
