import { inspectionVersionedPlan } from "../../../../entity/unit/inspection/inspectionVersionedPlan";
import { InspectionVersionedPlanViewModel } from "../../../../viewmodel/admin/unit/inspection/inspectionPlan.models";
import InspectionPointFactory from "./inspectionPoint";

export default abstract class InspectionVersionedPlanFactory {
  /**
   * @description map record to inspectionVersionedPlan
   * @param {inspectionVersionedPlan} record
   * @returns {InspectionVersionedPlanViewModel}
   */
  public static mapToSingle(record: inspectionVersionedPlan): InspectionVersionedPlanViewModel {
    return {
      id: record.id,
      version: record.version,
      created: record.createdAt,
      inspectionPoints: InspectionPointFactory.mapToBase(record.inspectionPoints),
    };
  }

  /**
   * @description map records to inspectionVersionedPlan
   * @param {Array<inspectionVersionedPlan>} records
   * @returns {Array<InspectionVersionedPlanViewModel>}
   */
  public static mapToBase(records: Array<inspectionVersionedPlan>): Array<InspectionVersionedPlanViewModel> {
    return records.map((r) => this.mapToSingle(r));
  }
}
