import { wearable } from "../../../../entity/unit/wearable/wearable";
import {
  MinifiedWearableViewModel,
  WearableViewModel,
} from "../../../../viewmodel/admin/unit/wearable/wearable.models";
import MemberFactory from "../../club/member/member";
import WearableTypeFactory from "./wearableType";

export default abstract class WearableFactory {
  /**
   * @description map record to wearable
   * @param {wearable} record
   * @returns {WearableViewModel}
   */
  public static mapToSingle(record: wearable): WearableViewModel {
    return {
      id: record.id,
      code: record?.code,
      name: record.name,
      location: record.location,
      commissioned: record.commissioned,
      decommissioned: record?.decommissioned,
      wearableTypeId: record?.wearableTypeId,
      wearableType: record?.wearableType ? WearableTypeFactory.mapToSingle(record.wearableType) : null,
      wearerId: record?.wearerId,
      wearer: record?.wearer ? MemberFactory.mapToSingle(record.wearer) : null,
    };
  }

  /**
   * @description map records to wearable
   * @param {Array<wearable>} records
   * @returns {Array<WearableViewModel>}
   */
  public static mapToBase(records: Array<wearable>): Array<WearableViewModel> {
    return records.map((r) => this.mapToSingle(r));
  }

  /**
   * @description map record to minifed wearable
   * @param {wearable} record
   * @returns {MinifiedWearableViewModel}
   */
  public static mapToSingleMinified(record: wearable): MinifiedWearableViewModel {
    return {
      id: record.id,
      code: record?.code,
      name: record.name,
      type: record?.wearableType.type,
      assigned: "wearable",
    };
  }

  /**
   * @description map records to minified wearable
   * @param {Array<wearable>} records
   * @returns {Array<MinifiedWearableViewModel>}
   */
  public static mapToBaseMinifed(records: Array<wearable>): Array<MinifiedWearableViewModel> {
    return records.map((r) => this.mapToSingleMinified(r));
  }
}
