import multer from "multer";
import { FileSystemHelper } from "../helpers/fileSystemHelper";
import path from "path";
import BadRequestException from "../exceptions/badRequestException";
import { v4 as uuid } from "uuid";

/**Settings image upload */
export const clubImageStorage = multer.diskStorage({
  destination: FileSystemHelper.formatPath("/app"),
  filename: function (req, file, cb) {
    const fileExtension = path.extname(file.originalname).toLowerCase();

    if (file.fieldname === "icon") {
      cb(null, "admin-icon" + fileExtension);
    } else if (file.fieldname === "logo") {
      cb(null, "admin-logo" + fileExtension);
    } else {
      cb(null, file.originalname);
    }
  },
});

export const clubImageMulter = multer({
  storage: clubImageStorage,
  fileFilter(req, file, cb) {
    if (file.mimetype.startsWith("image/png")) {
      cb(null, true);
    } else {
      cb(new BadRequestException("Wrong file format"));
    }
  },
});

export const clubImageUpload = clubImageMulter.fields([
  { name: "icon", maxCount: 1 },
  { name: "logo", maxCount: 1 },
]);

/**Inspection file upload */
export const inspectionFileStorage = multer.diskStorage({
  destination: function (req, file, cb) {
    FileSystemHelper.createFolder("inspection", req.params.id);
    cb(null, FileSystemHelper.formatPath("inspection", req.params.id));
  },
  filename: function (req, file, cb) {
    cb(null, file.originalname);
  },
});

export const inspectionFileMulter = multer({
  storage: inspectionFileStorage,
  fileFilter(req, file, cb) {
    if (file.mimetype.startsWith("image/") || file.mimetype === "application/pdf") {
      cb(null, true);
    } else {
      cb(new BadRequestException("Wrong file format"));
    }
  },
});

export const inspectionFileUpload = inspectionFileMulter.array("files");

/**public damage report upload */
export const pDamageReportFileStorage = multer.diskStorage({
  destination: function (req, file, cb) {
    FileSystemHelper.createFolder("damageReport");
    cb(null, FileSystemHelper.formatPath("damageReport"));
  },
  filename: function (req, file, cb) {
    const fileExtension = path.extname(file.originalname).toLowerCase();
    cb(null, uuid() + fileExtension);
  },
});

export const pDamageReportFileMulter = multer({
  storage: pDamageReportFileStorage,
  fileFilter(req, file, cb) {
    if (file.mimetype.startsWith("image/")) {
      cb(null, true);
    } else {
      cb(new BadRequestException("Wrong file format"));
    }
  },
});

export const pDamageReportFileUpload = pDamageReportFileMulter.array("images");
