import { MigrationInterface, QueryRunner } from "typeorm";
import {
  inspection_plan_table,
  inspection_versioned_plan_table,
  inspection_point_table,
  inspection_table,
  inspection_point_result_table,
} from "./baseSchemaTables/inspection";
import {
  equipment_type_table,
  equipment_table,
  vehicle_type_table,
  vehicle_table,
  wearable_type_table,
  wearable_table,
} from "./baseSchemaTables/unit";
import { maintenance_table, damage_report_table, repair_table } from "./baseSchemaTables/unit_extend";
import { availableTemplates } from "../type/templateTypes";
import { template_usage_table } from "./baseSchemaTables/query_template";

export class UnitBase1752914551204 implements MigrationInterface {
  name = "UnitBase1752914551204";

  public async up(queryRunner: QueryRunner): Promise<void> {
    await queryRunner.createTable(equipment_type_table, true, true, true);
    await queryRunner.createTable(equipment_table, true, true, true);
    await queryRunner.createTable(vehicle_type_table, true, true, true);
    await queryRunner.createTable(vehicle_table, true, true, true);
    await queryRunner.createTable(wearable_type_table, true, true, true);
    await queryRunner.createTable(wearable_table, true, true, true);

    await queryRunner.createTable(maintenance_table, true, true, true);
    await queryRunner.createTable(repair_table, true, true, true);
    await queryRunner.createTable(damage_report_table, true, true, true);

    await queryRunner.createTable(inspection_plan_table, true, true, true);
    await queryRunner.createTable(inspection_versioned_plan_table, true, true, true);
    await queryRunner.createTable(inspection_point_table, true, true, true);

    await queryRunner.createTable(inspection_table, true, true, true);
    await queryRunner.createTable(inspection_point_result_table, true, true, true);

    await queryRunner.manager
      .createQueryBuilder()
      .insert()
      .into(template_usage_table.name)
      .values(
        availableTemplates.map((at) => ({
          scope: at,
        }))
      )
      .orIgnore()
      .execute();
  }

  public async down(queryRunner: QueryRunner): Promise<void> {
    await queryRunner.dropTable(inspection_point_result_table, true, true, true);
    await queryRunner.dropTable(inspection_table, true, true, true);

    await queryRunner.dropTable(inspection_point_table, true, true, true);
    await queryRunner.dropTable(inspection_versioned_plan_table, true, true, true);
    await queryRunner.dropTable(inspection_plan_table, true, true, true);

    await queryRunner.dropTable(damage_report_table, true, true, true);
    await queryRunner.dropTable(repair_table, true, true, true);
    await queryRunner.dropTable(maintenance_table, true, true, true);

    await queryRunner.dropTable(wearable_table, true, true, true);
    await queryRunner.dropTable(wearable_type_table, true, true, true);
    await queryRunner.dropTable(vehicle_table, true, true, true);
    await queryRunner.dropTable(vehicle_type_table, true, true, true);
    await queryRunner.dropTable(equipment_table, true, true, true);
    await queryRunner.dropTable(equipment_type_table, true, true, true);

    await queryRunner.manager
      .createQueryBuilder()
      .delete()
      .from(template_usage_table.name)
      .where({ scope: "inspection" })
      .execute();
  }
}
