import { Table, TableForeignKey } from "typeorm";
import { getTypeByORM, isUUIDPrimary, getDefaultByORM } from "../ormHelper";

export const equipment_table = new Table({
  name: "equipment",
  columns: [
    { name: "id", ...getTypeByORM("uuid"), ...isUUIDPrimary },
    { name: "code", ...getTypeByORM("varchar", true), isUnique: true },
    { name: "name", ...getTypeByORM("varchar") },
    { name: "location", ...getTypeByORM("varchar") },
    { name: "commissioned", ...getTypeByORM("date") },
    { name: "decommissioned", ...getTypeByORM("date", true) },
    { name: "equipmentTypeId", ...getTypeByORM("uuid") },
  ],
  foreignKeys: [
    new TableForeignKey({
      columnNames: ["equipmentTypeId"],
      referencedColumnNames: ["id"],
      referencedTableName: "equipment_type",
      onDelete: "RESTRICT",
      onUpdate: "RESTRICT",
    }),
  ],
});

export const equipment_type_table = new Table({
  name: "equipment_type",
  columns: [
    { name: "id", ...getTypeByORM("uuid"), ...isUUIDPrimary },
    { name: "type", ...getTypeByORM("varchar"), isUnique: true },
    { name: "description", ...getTypeByORM("text", true) },
  ],
});

export const vehicle_table = new Table({
  name: "vehicle",
  columns: [
    { name: "id", ...getTypeByORM("uuid"), ...isUUIDPrimary },
    { name: "code", ...getTypeByORM("varchar", true), isUnique: true },
    { name: "name", ...getTypeByORM("varchar") },
    { name: "location", ...getTypeByORM("varchar") },
    { name: "commissioned", ...getTypeByORM("date") },
    { name: "decommissioned", ...getTypeByORM("date", true) },
    { name: "vehicleTypeId", ...getTypeByORM("uuid") },
  ],
  foreignKeys: [
    new TableForeignKey({
      columnNames: ["vehicleTypeId"],
      referencedColumnNames: ["id"],
      referencedTableName: "vehicle_type",
      onDelete: "RESTRICT",
      onUpdate: "RESTRICT",
    }),
  ],
});

export const vehicle_type_table = new Table({
  name: "vehicle_type",
  columns: [
    { name: "id", ...getTypeByORM("uuid"), ...isUUIDPrimary },
    { name: "type", ...getTypeByORM("varchar"), isUnique: true },
    { name: "description", ...getTypeByORM("text", true) },
  ],
});

export const wearable_table = new Table({
  name: "wearable",
  columns: [
    { name: "id", ...getTypeByORM("uuid"), ...isUUIDPrimary },
    { name: "code", ...getTypeByORM("varchar", true), isUnique: true },
    { name: "name", ...getTypeByORM("varchar") },
    { name: "location", ...getTypeByORM("varchar") },
    { name: "commissioned", ...getTypeByORM("date") },
    { name: "decommissioned", ...getTypeByORM("date", true) },
    { name: "wearableTypeId", ...getTypeByORM("uuid") },
    { name: "wearerId", ...getTypeByORM("uuid", true) },
  ],
  foreignKeys: [
    new TableForeignKey({
      columnNames: ["wearableTypeId"],
      referencedColumnNames: ["id"],
      referencedTableName: "wearable_type",
      onDelete: "RESTRICT",
      onUpdate: "RESTRICT",
    }),
    new TableForeignKey({
      columnNames: ["wearerId"],
      referencedColumnNames: ["id"],
      referencedTableName: "member",
      onDelete: "SET NULL",
      onUpdate: "RESTRICT",
    }),
  ],
});

export const wearable_type_table = new Table({
  name: "wearable_type",
  columns: [
    { name: "id", ...getTypeByORM("uuid"), ...isUUIDPrimary },
    { name: "type", ...getTypeByORM("varchar"), isUnique: true },
    { name: "description", ...getTypeByORM("text", true) },
  ],
});
