export type ORMType = "int" | "bigint" | "boolean" | "date" | "datetime" | "time" | "text" | "varchar" | "uuid";
export type ORMDefault = "currentTimestamp" | "string" | "boolean" | "number" | "null";
export type ColumnConfig = {
  type: string;
  length?: string;
  precision?: number;
  isNullable: boolean;
};
export type Primary = {
  isPrimary: boolean;
  isGenerated: boolean;
  generationStrategy: "increment" | "uuid" | "rowid" | "identity";
};

export function getTypeByORM(type: ORMType, nullable: boolean = false, length: number = 255): ColumnConfig {
  const typeMap: Record<ORMType, string> = {
    int: "integer",
    bigint: "bigint",
    boolean: "boolean",
    date: "date",
    datetime: "timestamp",
    time: "time",
    text: "text",
    varchar: "character varying",
    uuid: "uuid",
  };

  let obj: ColumnConfig = {
    type: typeMap[type] || type,
    isNullable: nullable,
  };
  if (type == "datetime") obj.precision = length;
  else if (obj.type == "varchar" || type == "varchar") obj.length = `${length}`;

  return obj;
}

export function getDefaultByORM<T = string | null>(type: ORMDefault, data?: string | number | boolean): T {
  const typeMap: Record<ORMDefault, string | null> = {
    currentTimestamp: `now()`,
    string: `'${data ?? ""}'`,
    boolean: Boolean(data) == true ? "true" : "false",
    number: Number(data).toString(),
    null: null,
  };

  return (typeMap[type] || type) as T;
}

export const isIncrementPrimary: Primary = {
  isPrimary: true,
  isGenerated: true,
  generationStrategy: "increment",
};

export const isUUIDPrimary: Primary = {
  isPrimary: true,
  isGenerated: true,
  generationStrategy: "uuid",
};
