import express, { Request, Response } from "express";
import {
  getCalendarItemById,
  getAllCalendarItems,
  getAllCalendarTypes,
  getCalendarTypeById,
  createCalendarItem,
  createCalendarType,
  updateCalendarItem,
  updateCalendarType,
  deleteCalendarItem,
  deleteCalendarType,
} from "../../../controller/admin/club/calendarController";
import PermissionHelper from "../../../helpers/permissionHelper";

var router = express.Router({ mergeParams: true });

router.get("/", async (req: Request, res: Response) => {
  await getAllCalendarItems(req, res);
});

router.get("/:id", async (req: Request, res: Response) => {
  await getCalendarItemById(req, res);
});

router.post(
  "/",
  PermissionHelper.passCheckMiddleware("create", "club", "calendar"),
  async (req: Request, res: Response) => {
    await createCalendarItem(req, res);
  }
);

router.patch(
  "/:id",
  PermissionHelper.passCheckMiddleware("update", "club", "calendar"),
  async (req: Request, res: Response) => {
    await updateCalendarItem(req, res);
  }
);

router.delete(
  "/:id",
  PermissionHelper.passCheckMiddleware("delete", "club", "calendar"),
  async (req: Request, res: Response) => {
    await deleteCalendarItem(req, res);
  }
);

export default router;
