import express, { Request, Response } from "express";
import {
  createAward,
  deleteAward,
  getAllAwards,
  getAwardById,
  updateAward,
} from "../../../controller/admin/configuration/awardController";
import PermissionHelper from "../../../helpers/permissionHelper";

var router = express.Router({ mergeParams: true });

router.get("/", async (req: Request, res: Response) => {
  await getAllAwards(req, res);
});

router.get("/:id", async (req: Request, res: Response) => {
  await getAwardById(req, res);
});

router.post(
  "/",
  PermissionHelper.passCheckMiddleware("create", "configuration", "award"),
  async (req: Request, res: Response) => {
    await createAward(req, res);
  }
);

router.patch(
  "/:id",
  PermissionHelper.passCheckMiddleware("update", "configuration", "award"),
  async (req: Request, res: Response) => {
    await updateAward(req, res);
  }
);

router.delete(
  "/:id",
  PermissionHelper.passCheckMiddleware("delete", "configuration", "award"),
  async (req: Request, res: Response) => {
    await deleteAward(req, res);
  }
);

export default router;
