import express, { Request, Response } from "express";
import {
  getCalendarItemById,
  getAllCalendarItems,
  getAllCalendarTypes,
  getCalendarTypeById,
  createCalendarItem,
  createCalendarType,
  updateCalendarItem,
  updateCalendarType,
  deleteCalendarItem,
  deleteCalendarType,
} from "../../../controller/admin/club/calendarController";
import PermissionHelper from "../../../helpers/permissionHelper";

var router = express.Router({ mergeParams: true });

router.get("/", async (req: Request, res: Response) => {
  await getAllCalendarTypes(req, res);
});

router.get("/:id", async (req: Request, res: Response) => {
  await getCalendarTypeById(req, res);
});

router.post(
  "/",
  PermissionHelper.passCheckMiddleware("create", "configuration", "calendar_type"),
  async (req: Request, res: Response) => {
    await createCalendarType(req, res);
  }
);

router.patch(
  "/:id",
  PermissionHelper.passCheckMiddleware("update", "configuration", "calendar_type"),
  async (req: Request, res: Response) => {
    await updateCalendarType(req, res);
  }
);

router.delete(
  "/:id",
  PermissionHelper.passCheckMiddleware("delete", "configuration", "calendar_type"),
  async (req: Request, res: Response) => {
    await deleteCalendarType(req, res);
  }
);

export default router;
