import express, { Request, Response } from "express";
import {
  createCommunicationType,
  deleteCommunicationType,
  getAllCommunicationTypes,
  getCommunicationTypeAvailableColumns,
  getCommunicationTypeById,
  updateCommunicationType,
} from "../../../controller/admin/configuration/communicationTypeController";
import PermissionHelper from "../../../helpers/permissionHelper";

var router = express.Router({ mergeParams: true });

router.get("/", async (req: Request, res: Response) => {
  await getAllCommunicationTypes(req, res);
});

router.get("/fields", async (req: Request, res: Response) => {
  await getCommunicationTypeAvailableColumns(req, res);
});

router.get("/:id", async (req: Request, res: Response) => {
  await getCommunicationTypeById(req, res);
});

router.post(
  "/",
  PermissionHelper.passCheckMiddleware("create", "configuration", "communication_type"),
  async (req: Request, res: Response) => {
    await createCommunicationType(req, res);
  }
);

router.patch(
  "/:id",
  PermissionHelper.passCheckMiddleware("update", "configuration", "communication_type"),
  async (req: Request, res: Response) => {
    await updateCommunicationType(req, res);
  }
);

router.delete(
  "/:id",
  PermissionHelper.passCheckMiddleware("delete", "configuration", "communication_type"),
  async (req: Request, res: Response) => {
    await deleteCommunicationType(req, res);
  }
);

export default router;
