import express, { Request, Response } from "express";
import {
  createEducation,
  deleteEducation,
  getAllEducations,
  getEducationById,
  updateEducation,
} from "../../../controller/admin/configuration/educationController";
import PermissionHelper from "../../../helpers/permissionHelper";

var router = express.Router({ mergeParams: true });

router.get("/", async (req: Request, res: Response) => {
  await getAllEducations(req, res);
});

router.get("/:id", async (req: Request, res: Response) => {
  await getEducationById(req, res);
});

router.post(
  "/",
  PermissionHelper.passCheckMiddleware("create", "configuration", "education"),
  async (req: Request, res: Response) => {
    await createEducation(req, res);
  }
);

router.patch(
  "/:id",
  PermissionHelper.passCheckMiddleware("update", "configuration", "education"),
  async (req: Request, res: Response) => {
    await updateEducation(req, res);
  }
);

router.delete(
  "/:id",
  PermissionHelper.passCheckMiddleware("delete", "configuration", "education"),
  async (req: Request, res: Response) => {
    await deleteEducation(req, res);
  }
);

export default router;
