import express, { Request, Response } from "express";
import {
  createExecutivePosition,
  deleteExecutivePosition,
  getAllExecutivePositions,
  getExecutivePositionById,
  updateExecutivePosition,
} from "../../../controller/admin/configuration/executivePositionController";
import PermissionHelper from "../../../helpers/permissionHelper";

var router = express.Router({ mergeParams: true });

router.get("/", async (req: Request, res: Response) => {
  await getAllExecutivePositions(req, res);
});

router.get("/:id", async (req: Request, res: Response) => {
  await getExecutivePositionById(req, res);
});

router.post(
  "/",
  PermissionHelper.passCheckMiddleware("create", "configuration", "executive_position"),
  async (req: Request, res: Response) => {
    await createExecutivePosition(req, res);
  }
);

router.patch(
  "/:id",
  PermissionHelper.passCheckMiddleware("update", "configuration", "executive_position"),
  async (req: Request, res: Response) => {
    await updateExecutivePosition(req, res);
  }
);

router.delete(
  "/:id",
  PermissionHelper.passCheckMiddleware("delete", "configuration", "executive_position"),
  async (req: Request, res: Response) => {
    await deleteExecutivePosition(req, res);
  }
);

export default router;
