import express, { Request, Response } from "express";
import {
  createMembershipStatus,
  deleteMembershipStatus,
  getAllMembershipStatus,
  getMembershipStatusById,
  updateMembershipStatus,
} from "../../../controller/admin/configuration/membershipStatusController";
import PermissionHelper from "../../../helpers/permissionHelper";

var router = express.Router({ mergeParams: true });

router.get("/", async (req: Request, res: Response) => {
  await getAllMembershipStatus(req, res);
});

router.get("/:id", async (req: Request, res: Response) => {
  await getMembershipStatusById(req, res);
});

router.post(
  "/",
  PermissionHelper.passCheckMiddleware("create", "configuration", "membership_status"),
  async (req: Request, res: Response) => {
    await createMembershipStatus(req, res);
  }
);

router.patch(
  "/:id",
  PermissionHelper.passCheckMiddleware("update", "configuration", "membership_status"),
  async (req: Request, res: Response) => {
    await updateMembershipStatus(req, res);
  }
);

router.delete(
  "/:id",
  PermissionHelper.passCheckMiddleware("delete", "configuration", "membership_status"),
  async (req: Request, res: Response) => {
    await deleteMembershipStatus(req, res);
  }
);

export default router;
