import express, { Request, Response } from "express";
import {
  createQualification,
  deleteQualification,
  getAllQualifications,
  getQualificationById,
  updateQualification,
} from "../../../controller/admin/configuration/qualificationController";
import PermissionHelper from "../../../helpers/permissionHelper";

var router = express.Router({ mergeParams: true });

router.get("/", async (req: Request, res: Response) => {
  await getAllQualifications(req, res);
});

router.get("/:id", async (req: Request, res: Response) => {
  await getQualificationById(req, res);
});

router.post(
  "/",
  PermissionHelper.passCheckMiddleware("create", "configuration", "qualification"),
  async (req: Request, res: Response) => {
    await createQualification(req, res);
  }
);

router.patch(
  "/:id",
  PermissionHelper.passCheckMiddleware("update", "configuration", "qualification"),
  async (req: Request, res: Response) => {
    await updateQualification(req, res);
  }
);

router.delete(
  "/:id",
  PermissionHelper.passCheckMiddleware("delete", "configuration", "qualification"),
  async (req: Request, res: Response) => {
    await deleteQualification(req, res);
  }
);

export default router;
