import express, { Request, Response } from "express";
import {
  cloneTemplate,
  createTemplate,
  deleteTemplate,
  getAllTemplates,
  getTemplateById,
  updateTemplate,
} from "../../../controller/admin/configuration/templateController";
import PermissionHelper from "../../../helpers/permissionHelper";

var router = express.Router({ mergeParams: true });

router.get("/", async (req: Request, res: Response) => {
  await getAllTemplates(req, res);
});

router.get("/:id", async (req: Request, res: Response) => {
  await getTemplateById(req, res);
});

router.post(
  "/",
  PermissionHelper.passCheckMiddleware("create", "configuration", "template"),
  async (req: Request, res: Response) => {
    await createTemplate(req, res);
  }
);

router.post(
  "/clone",
  PermissionHelper.passCheckMiddleware("create", "configuration", "template"),
  async (req: Request, res: Response) => {
    await cloneTemplate(req, res);
  }
);

router.patch(
  "/:id",
  PermissionHelper.passCheckMiddleware("update", "configuration", "template"),
  async (req: Request, res: Response) => {
    await updateTemplate(req, res);
  }
);

router.delete(
  "/:id",
  PermissionHelper.passCheckMiddleware("delete", "configuration", "template"),
  async (req: Request, res: Response) => {
    await deleteTemplate(req, res);
  }
);

export default router;
