import express, { Request, Response } from "express";
import PermissionHelper from "../../../helpers/permissionHelper";
import {
  getAllTemplateUsages,
  printTemplateUsageDemo,
  updateTemplateUsage,
} from "../../../controller/admin/configuration/templateUsageController";
import { PermissionModule } from "../../../type/permissionTypes";
import ForbiddenRequestException from "../../../exceptions/forbiddenRequestException";

var router = express.Router({ mergeParams: true });

router.get("/", async (req: Request, res: Response) => {
  await getAllTemplateUsages(req, res);
});

router.get("/:scope", async (req: Request, res: Response) => {
  await printTemplateUsageDemo(req, res);
});

router.patch(
  "/:scope",
  PermissionHelper.passCheckMiddleware("update", "configuration", "template_usage"),
  async (req: Request, res: Response) => {
    await updateTemplateUsage(req, res);
  }
);

export default router;
