import express, { Request, Response } from "express";
import PermissionHelper from "../../../helpers/permissionHelper";
import {
  createRole,
  deleteRole,
  getAllRoles,
  getRoleById,
  getRolePermissions,
  updateRole,
  updateRolePermissions,
} from "../../../controller/admin/management/roleController";

var router = express.Router({ mergeParams: true });

router.get("/", async (req: Request, res: Response) => {
  await getAllRoles(req, res);
});

router.get("/:id", async (req: Request, res: Response) => {
  await getRoleById(req, res);
});

router.get("/:id/permissions", async (req: Request, res: Response) => {
  await getRolePermissions(req, res);
});

router.post(
  "/",
  PermissionHelper.passCheckMiddleware("create", "management", "role"),
  async (req: Request, res: Response) => {
    await createRole(req, res);
  }
);

router.patch(
  "/:id",
  PermissionHelper.passCheckMiddleware("update", "management", "role"),
  async (req: Request, res: Response) => {
    await updateRole(req, res);
  }
);

router.patch(
  "/:id/permissions",
  PermissionHelper.passCheckMiddleware("admin", "management", "role"),
  async (req: Request, res: Response) => {
    await updateRolePermissions(req, res);
  }
);

router.delete(
  "/:id",
  PermissionHelper.passCheckMiddleware("delete", "management", "role"),
  async (req: Request, res: Response) => {
    await deleteRole(req, res);
  }
);

export default router;
