import express, { Request, Response } from "express";
import PermissionHelper from "../../../helpers/permissionHelper";
import {
  getSetting,
  getSettings,
  resetSetting,
  setImages,
  setSetting,
  setSettings,
} from "../../../controller/admin/management/settingController";
import { clubImageUpload } from "../../../middleware/multer";

var router = express.Router({ mergeParams: true });

router.get("/", async (req: Request, res: Response) => {
  await getSettings(req, res);
});

router.get("/:setting", async (req: Request, res: Response) => {
  await getSetting(req, res);
});

router.put(
  "/",
  PermissionHelper.passCheckMiddleware("create", "management", "setting"),
  async (req: Request, res: Response) => {
    await setSetting(req, res);
  }
);

router.put(
  "/multi",
  PermissionHelper.passCheckMiddleware("create", "management", "setting"),
  async (req: Request, res: Response) => {
    await setSettings(req, res);
  }
);

router.put(
  "/images",
  PermissionHelper.passCheckMiddleware("create", "management", "setting"),
  clubImageUpload,
  async (req: Request, res: Response) => {
    await setImages(req, res);
  }
);

router.delete(
  "/:setting",
  PermissionHelper.passCheckMiddleware("delete", "management", "setting"),
  async (req: Request, res: Response) => {
    await resetSetting(req, res);
  }
);

export default router;
