import express, { Request, Response } from "express";
import PermissionHelper from "../../../helpers/permissionHelper";
import {
  deleteUser,
  getAllUsers,
  getUserById,
  getUserPermissions,
  getUserRoles,
  updateUser,
  updateUserPermissions,
  updateUserRoles,
} from "../../../controller/admin/management/userController";

var router = express.Router({ mergeParams: true });

router.get("/", async (req: Request, res: Response) => {
  await getAllUsers(req, res);
});

router.get("/:id", async (req: Request, res: Response) => {
  await getUserById(req, res);
});

router.get("/:id/permissions", async (req: Request, res: Response) => {
  await getUserPermissions(req, res);
});

router.get("/:id/roles", async (req: Request, res: Response) => {
  await getUserRoles(req, res);
});

router.patch(
  "/:id",
  PermissionHelper.passCheckMiddleware("update", "management", "user"),
  async (req: Request, res: Response) => {
    await updateUser(req, res);
  }
);

router.patch(
  "/:id/permissions",
  PermissionHelper.passCheckMiddleware("admin", "management", "user"),
  async (req: Request, res: Response) => {
    await updateUserPermissions(req, res);
  }
);

router.patch(
  "/:id/roles",
  PermissionHelper.passCheckMiddleware("update", "management", "user"),
  async (req: Request, res: Response) => {
    await updateUserRoles(req, res);
  }
);

router.delete(
  "/:id",
  PermissionHelper.passCheckMiddleware("delete", "management", "user"),
  async (req: Request, res: Response) => {
    await deleteUser(req, res);
  }
);

export default router;
