import express, { Request, Response } from "express";
import PermissionHelper from "../../../helpers/permissionHelper";
import {
  createWebapi,
  deleteWebapi,
  getAllWebapis,
  getWebapiById,
  getWebapiPermissions,
  getWebapiTokenById,
  updateWebapi,
  updateWebapiPermissions,
} from "../../../controller/admin/management/webapiController";

var router = express.Router({ mergeParams: true });

router.get("/", async (req: Request, res: Response) => {
  await getAllWebapis(req, res);
});

router.get("/:id", async (req: Request, res: Response) => {
  await getWebapiById(req, res);
});

router.get("/:id/token", async (req: Request, res: Response) => {
  await getWebapiTokenById(req, res);
});

router.get("/:id/permissions", async (req: Request, res: Response) => {
  await getWebapiPermissions(req, res);
});

router.post(
  "/",
  PermissionHelper.passCheckMiddleware("create", "management", "webapi"),
  async (req: Request, res: Response) => {
    await createWebapi(req, res);
  }
);

router.patch(
  "/:id",
  PermissionHelper.passCheckMiddleware("update", "management", "webapi"),
  async (req: Request, res: Response) => {
    await updateWebapi(req, res);
  }
);

router.patch(
  "/:id/permissions",
  PermissionHelper.passCheckMiddleware("admin", "management", "webapi"),
  async (req: Request, res: Response) => {
    await updateWebapiPermissions(req, res);
  }
);

router.delete(
  "/:id",
  PermissionHelper.passCheckMiddleware("delete", "management", "webapi"),
  async (req: Request, res: Response) => {
    await deleteWebapi(req, res);
  }
);

export default router;
