import express, { Request, Response } from "express";
import PermissionHelper from "../../../helpers/permissionHelper";
import {
  createInspection,
  deleteInspectionById,
  getAllInspectionsForRelated,
  getInspectionById,
  updateInspectionById,
} from "../../../controller/admin/unit/inspectionController";
import {
  getAllDamageReportsByStatus,
  getAllDamageReportsForRelated,
  getDamageReportById,
  getDamageReportsByIds,
  provideDamageReportImageUpload,
  updateDamageReportById,
} from "../../../controller/admin/unit/damageReportController";

var router = express.Router({ mergeParams: true });

router.get("/", async (req: Request, res: Response) => {
  await getAllDamageReportsByStatus(req, res);
});

router.get(
  ["/vehicle/:relatedId", "/equipment/:relatedId", "/wearable/:relatedId"],
  async (req: Request, res: Response) => {
    if (req.path.startsWith("/vehicle")) {
      req.params.related = "vehicle";
    } else if (req.path.startsWith("/equipment")) {
      req.params.related = "equipment";
    } else {
      req.params.related = "wearable";
    }

    await getAllDamageReportsForRelated(req, res);
  }
);

router.get("/:id", async (req: Request, res: Response) => {
  await getDamageReportById(req, res);
});

router.post("/ids", async (req: Request, res: Response) => {
  await getDamageReportsByIds(req, res);
});

router.get("/:id/:filename", async (req: Request, res: Response) => {
  await provideDamageReportImageUpload(req, res);
});

router.patch(
  "/:id",
  PermissionHelper.passCheckMiddleware("update", "unit", "inspection"),
  async (req: Request, res: Response) => {
    await updateDamageReportById(req, res);
  }
);

export default router;
