import express, { Request, Response } from "express";
import PermissionHelper from "../../../helpers/permissionHelper";
import {
  createEquipmentType,
  deleteEquipmentTypeById,
  getAllEquipmentTypes,
  getEquipmentTypeById,
  updateEquipmentTypeById,
} from "../../../controller/admin/unit/equipmentTypeController";

var router = express.Router({ mergeParams: true });

router.get("/", async (req: Request, res: Response) => {
  await getAllEquipmentTypes(req, res);
});

router.get("/:id", async (req: Request, res: Response) => {
  await getEquipmentTypeById(req, res);
});

router.post(
  "/",
  PermissionHelper.passCheckMiddleware("create", "unit", "equipment_type"),
  async (req: Request, res: Response) => {
    await createEquipmentType(req, res);
  }
);

router.patch(
  "/:id",
  PermissionHelper.passCheckMiddleware("update", "unit", "equipment_type"),
  async (req: Request, res: Response) => {
    await updateEquipmentTypeById(req, res);
  }
);

router.delete(
  "/:id",
  PermissionHelper.passCheckMiddleware("delete", "unit", "equipment_type"),
  async (req: Request, res: Response) => {
    await deleteEquipmentTypeById(req, res);
  }
);

export default router;
