import express, { Request, Response } from "express";
import PermissionHelper from "../../../helpers/permissionHelper";
import {
  createInspectionPlan,
  deleteInspectionPlanById,
  getAllInspectionPlans,
  getAllInspectionPlansForRelated,
  getInspectionPlanById,
  getInspectionPointsByPlanId,
  updateInspectionPlanById,
  updateInspectionPointsByPlanId,
} from "../../../controller/admin/unit/inspectionPlanController";

var router = express.Router({ mergeParams: true });

router.get("/", async (req: Request, res: Response) => {
  await getAllInspectionPlans(req, res);
});

router.get("/:id/points", async (req: Request, res: Response) => {
  await getInspectionPointsByPlanId(req, res);
});

router.get(
  ["/vehicleType/:relatedTypeId", "/equipmentType/:relatedTypeId", "/wearableType/:relatedTypeId"],
  async (req: Request, res: Response) => {
    if (req.path.startsWith("/vehicleType")) {
      req.params.related = "vehicleType";
    } else if (req.path.startsWith("/equipmentType")) {
      req.params.related = "equipmentType";
    } else {
      req.params.related = "wearableType";
    }

    await getAllInspectionPlansForRelated(req, res);
  }
);

router.get("/:id", async (req: Request, res: Response) => {
  await getInspectionPlanById(req, res);
});

router.post(
  "/",
  PermissionHelper.passCheckMiddleware("create", "unit", "inspection_plan"),
  async (req: Request, res: Response) => {
    await createInspectionPlan(req, res);
  }
);

router.patch(
  "/:id",
  PermissionHelper.passCheckMiddleware("update", "unit", "inspection_plan"),
  async (req: Request, res: Response) => {
    await updateInspectionPlanById(req, res);
  }
);

router.patch(
  "/:id/points",
  PermissionHelper.passCheckMiddleware("update", "unit", "inspection_plan"),
  async (req: Request, res: Response) => {
    await updateInspectionPointsByPlanId(req, res);
  }
);

router.delete(
  "/:id",
  PermissionHelper.passCheckMiddleware("delete", "unit", "inspection_plan"),
  async (req: Request, res: Response) => {
    await deleteInspectionPlanById(req, res);
  }
);

export default router;
