import express, { Request, Response } from "express";
import PermissionHelper from "../../../helpers/permissionHelper";
import {
  getAllMaintenancesByStatus,
  getAllMaintenancesForRelated,
  getMaintenanceById,
  updateMaintenanceById,
} from "../../../controller/admin/unit/maintenanceController";

var router = express.Router({ mergeParams: true });

router.get("/", async (req: Request, res: Response) => {
  await getAllMaintenancesByStatus(req, res);
});

router.get(
  ["/vehicle/:relatedId", "/equipment/:relatedId", "/wearable/:relatedId"],
  async (req: Request, res: Response) => {
    if (req.path.startsWith("/vehicle")) {
      req.params.related = "vehicle";
    } else if (req.path.startsWith("/equipment")) {
      req.params.related = "equipment";
    } else {
      req.params.related = "wearable";
    }

    await getAllMaintenancesForRelated(req, res);
  }
);

router.get("/:id", async (req: Request, res: Response) => {
  await getMaintenanceById(req, res);
});

router.patch(
  "/:id",
  PermissionHelper.passCheckMiddleware("update", "unit", "inspection"),
  async (req: Request, res: Response) => {
    await updateMaintenanceById(req, res);
  }
);

export default router;
