import express, { Request, Response } from "express";
import PermissionHelper from "../../../helpers/permissionHelper";
import {
  createVehicle,
  deleteVehicleById,
  getAllVehicles,
  getVehicleById,
  getVehiclesByIds,
  updateVehicleById,
} from "../../../controller/admin/unit/vehicleController";

var router = express.Router({ mergeParams: true });

router.get("/", async (req: Request, res: Response) => {
  await getAllVehicles(req, res);
});

router.get("/:id", async (req: Request, res: Response) => {
  await getVehicleById(req, res);
});

router.post("/ids", async (req: Request, res: Response) => {
  await getVehiclesByIds(req, res);
});

router.post(
  "/",
  PermissionHelper.passCheckMiddleware("create", "unit", "vehicle"),
  async (req: Request, res: Response) => {
    await createVehicle(req, res);
  }
);

router.patch(
  "/:id",
  PermissionHelper.passCheckMiddleware("update", "unit", "vehicle"),
  async (req: Request, res: Response) => {
    await updateVehicleById(req, res);
  }
);

router.delete(
  "/:id",
  PermissionHelper.passCheckMiddleware("delete", "unit", "vehicle"),
  async (req: Request, res: Response) => {
    await deleteVehicleById(req, res);
  }
);

export default router;
