import express, { Request, Response } from "express";
import PermissionHelper from "../../../helpers/permissionHelper";
import {
  createVehicleType,
  deleteVehicleTypeById,
  getAllVehicleTypes,
  getVehicleTypeById,
  updateVehicleTypeById,
} from "../../../controller/admin/unit/vehicleTypeController";

var router = express.Router({ mergeParams: true });

router.get("/", async (req: Request, res: Response) => {
  await getAllVehicleTypes(req, res);
});

router.get("/:id", async (req: Request, res: Response) => {
  await getVehicleTypeById(req, res);
});

router.post(
  "/",
  PermissionHelper.passCheckMiddleware("create", "unit", "vehicle_type"),
  async (req: Request, res: Response) => {
    await createVehicleType(req, res);
  }
);

router.patch(
  "/:id",
  PermissionHelper.passCheckMiddleware("update", "unit", "vehicle_type"),
  async (req: Request, res: Response) => {
    await updateVehicleTypeById(req, res);
  }
);

router.delete(
  "/:id",
  PermissionHelper.passCheckMiddleware("delete", "unit", "vehicle_type"),
  async (req: Request, res: Response) => {
    await deleteVehicleTypeById(req, res);
  }
);

export default router;
