import express, { Request, Response } from "express";
import PermissionHelper from "../../../helpers/permissionHelper";
import {
  createWearable,
  deleteWearableById,
  getAllWearables,
  getWearableById,
  getWearablesByIds,
  updateWearableById,
} from "../../../controller/admin/unit/wearableController";

var router = express.Router({ mergeParams: true });

router.get("/", async (req: Request, res: Response) => {
  await getAllWearables(req, res);
});

router.get("/:id", async (req: Request, res: Response) => {
  await getWearableById(req, res);
});

router.post("/ids", async (req: Request, res: Response) => {
  await getWearablesByIds(req, res);
});

router.post(
  "/",
  PermissionHelper.passCheckMiddleware("create", "unit", "wearable"),
  async (req: Request, res: Response) => {
    await createWearable(req, res);
  }
);

router.patch(
  "/:id",
  PermissionHelper.passCheckMiddleware("update", "unit", "wearable"),
  async (req: Request, res: Response) => {
    await updateWearableById(req, res);
  }
);

router.delete(
  "/:id",
  PermissionHelper.passCheckMiddleware("delete", "unit", "wearable"),
  async (req: Request, res: Response) => {
    await deleteWearableById(req, res);
  }
);

export default router;
