import express from "express";
import {
  checkScannerRoomExists,
  createDamageReport,
  getApplicationConfig,
  getApplicationFavicon,
  getApplicationIcon,
  getApplicationLogo,
  getApplicationManifest,
  getCalendarItemsByTypes,
  searchStuffByCode,
} from "../controller/publicController";
import { pDamageReportFileUpload } from "../middleware/multer";

var router = express.Router({ mergeParams: true });

router.get("/calendar", async (req, res) => {
  await getCalendarItemsByTypes(req, res);
});

router.get("/reportdamage", async (req, res) => {
  await searchStuffByCode(req, res);
});

router.post("/reportdamage", pDamageReportFileUpload, async (req, res) => {
  await createDamageReport(req, res);
});

router.post("/checkscannerroom", async (req, res) => {
  await checkScannerRoomExists(req, res);
});

router.get("/configuration", async (req, res) => {
  await getApplicationConfig(req, res);
});

router.get("/manifest.webmanifest", async (req, res) => {
  await getApplicationManifest(req, res);
});

router.get("/applogo.png", async (req, res) => {
  await getApplicationLogo(req, res);
});

router.get("/favicon.ico", async (req, res) => {
  await getApplicationFavicon(req, res);
});

router.get("/icon.png", async (req, res) => {
  await getApplicationIcon(req, res);
});

export default router;
