import { dataSource } from "../../../data-source";
import { memberAwards } from "../../../entity/club/member/memberAwards";
import DatabaseActionException from "../../../exceptions/databaseActionException";
import InternalException from "../../../exceptions/internalException";

export default abstract class MemberAwardService {
  /**
   * @description get all by member id
   * @param {string} memberId
   * @returns {Promise<Array<memberAwards>>}
   */
  static async getAll(memberId: string): Promise<Array<memberAwards>> {
    return await dataSource
      .getRepository(memberAwards)
      .createQueryBuilder("memberAwards")
      .leftJoinAndSelect("memberAwards.award", "award")
      .where("memberAwards.memberId = :memberId", { memberId: memberId })
      .orderBy("award.award", "ASC")
      .getMany()
      .then((res) => {
        return res;
      })
      .catch((err) => {
        throw new DatabaseActionException("SELECT", "memberAwards", err);
      });
  }

  /**
   * @description get by memberId and recordId
   * @param {string} memberId
   * @param {number} recordId
   * @returns {Promise<Array<member>>}
   */
  static async getById(memberId: string, recordId: number): Promise<memberAwards> {
    return await dataSource
      .getRepository(memberAwards)
      .createQueryBuilder("memberAwards")
      .leftJoinAndSelect("memberAwards.award", "award")
      .where("memberAwards.memberId = :memberId", { memberId: memberId })
      .andWhere("memberAwards.id = :recordId", { recordId: recordId })
      .getOneOrFail()
      .then((res) => {
        return res;
      })
      .catch((err) => {
        throw new DatabaseActionException("SELECT", "memberAwards", err);
      });
  }
}
