import { dataSource } from "../../../data-source";
import { memberQualifications } from "../../../entity/club/member/memberQualifications";
import DatabaseActionException from "../../../exceptions/databaseActionException";
import InternalException from "../../../exceptions/internalException";

export default abstract class MemberQualificationService {
  /**
   * @description get all by member id
   * @param {string} memberId
   * @returns {Promise<Array<memberQualifications>>}
   */
  static async getAll(memberId: string): Promise<Array<memberQualifications>> {
    return await dataSource
      .getRepository(memberQualifications)
      .createQueryBuilder("memberQualifications")
      .leftJoinAndSelect("memberQualifications.qualification", "qualification")
      .where("memberQualifications.memberId = :memberId", { memberId: memberId })
      .orderBy("qualification.qualification", "ASC")
      .getMany()
      .then((res) => {
        return res;
      })
      .catch((err) => {
        throw new DatabaseActionException("SELECT", "memberQualifications", err);
      });
  }

  /**
   * @description get by memberId and recordId
   * @param {string} memberId
   * @param {number} recordId
   * @returns {Promise<Array<member>>}
   */
  static async getById(memberId: string, recordId: number): Promise<memberQualifications> {
    return await dataSource
      .getRepository(memberQualifications)
      .createQueryBuilder("memberQualifications")
      .leftJoinAndSelect("memberQualifications.qualification", "qualification")
      .where("memberQualifications.memberId = :memberId", { memberId: memberId })
      .andWhere("memberQualifications.id = :recordId", { recordId: recordId })
      .getOneOrFail()
      .then((res) => {
        return res;
      })
      .catch((err) => {
        throw new DatabaseActionException("SELECT", "memberQualifications", err);
      });
  }
}
