import { dataSource } from "../../../data-source";
import { newsletterDates } from "../../../entity/club/newsletter/newsletterDates";
import { member } from "../../../entity/club/member/member";
import InternalException from "../../../exceptions/internalException";
import DatabaseActionException from "../../../exceptions/databaseActionException";

export default abstract class NewsletterDatesService {
  /**
   * @description get all newsletterDates
   * @returns {Promise<Array<newsletterDates>>}
   */
  static async getAll(newsletterId: number): Promise<Array<newsletterDates>> {
    return await dataSource
      .getRepository(newsletterDates)
      .createQueryBuilder("newsletterDates")
      .leftJoinAndSelect("newsletterDates.calendar", "calendar")
      .leftJoinAndSelect("calendar.type", "type")
      .leftJoinAndSelect("newsletterDates.newsletter", "newsletter")
      .where("newsletterDates.newsletterId = :id", { id: newsletterId })
      .getMany()
      .then((res) => {
        return res;
      })
      .catch((err) => {
        throw new DatabaseActionException("SELECT", "newsletterDates", err);
      });
  }
}
