import { dataSource } from "../../../data-source";
import { protocolDecision } from "../../../entity/club/protocol/protocolDecision";
import DatabaseActionException from "../../../exceptions/databaseActionException";
import InternalException from "../../../exceptions/internalException";

export default abstract class ProtocolDecisionService {
  /**
   * @description get all protocolDecisionss
   * @returns {Promise<Array<protocolDecision>>}
   */
  static async getAll(protocolId: number): Promise<Array<protocolDecision>> {
    return await dataSource
      .getRepository(protocolDecision)
      .createQueryBuilder("protocolDecisions")
      .where("protocolDecisions.protocolId = :protocolId", { protocolId })
      .getMany()
      .then((res) => {
        return res;
      })
      .catch((err) => {
        throw new DatabaseActionException("SELECT", "protocolDecision", err);
      });
  }

  /**
   * @description get protocolDecision by id
   * @returns {Promise<protocolDecision>}
   */
  static async getById(id: number): Promise<protocolDecision> {
    return await dataSource
      .getRepository(protocolDecision)
      .createQueryBuilder("protocolDecisions")
      .where("protocolDecisions.id = :id", { id: id })
      .getOneOrFail()
      .then((res) => {
        return res;
      })
      .catch((err) => {
        throw new DatabaseActionException("SELECT", "protocolDecision", err);
      });
  }

  /**
   * @description get count of exisiting protocolDecision by protocolId
   * @returns {Promise<number>}
   */
  static async getInstanceCount(protocolId: number): Promise<number> {
    return await dataSource
      .getRepository(protocolDecision)
      .createQueryBuilder("protocolDecisions")
      .where({ protocolId })
      .getCount()
      .then((res) => {
        return res;
      })
      .catch((err) => {
        throw new DatabaseActionException("COUNT", "protocolDecision", err);
      });
  }
}
