import { dataSource } from "../../../data-source";
import { protocolPrintout } from "../../../entity/club/protocol/protocolPrintout";
import DatabaseActionException from "../../../exceptions/databaseActionException";
import InternalException from "../../../exceptions/internalException";

export default abstract class ProtocolPrintoutService {
  /**
   * @description get all protocolPrintouts
   * @returns {Promise<Array<protocolPrintout>>}
   */
  static async getAll(protocolId: number): Promise<Array<protocolPrintout>> {
    return await dataSource
      .getRepository(protocolPrintout)
      .createQueryBuilder("protocolPrintout")
      .where("protocolPrintout.protocolId = :protocolId", { protocolId })
      .getMany()
      .then((res) => {
        return res;
      })
      .catch((err) => {
        throw new DatabaseActionException("SELECT", "protocolPrintout", err);
      });
  }

  /**
   * @description get protocolPrintout by id
   * @returns {Promise<protocolPrintout>}
   */
  static async getById(id: number, protocolId: number): Promise<protocolPrintout> {
    return await dataSource
      .getRepository(protocolPrintout)
      .createQueryBuilder("protocolPrintout")
      .where("protocolPrintout.protocolId = :protocolId", { protocolId })
      .andWhere("protocolPrintout.id = :id", { id: id })
      .getOneOrFail()
      .then((res) => {
        return res;
      })
      .catch((err) => {
        throw new DatabaseActionException("SELECT", "protocolPrintout", err);
      });
  }

  /**
   * @description get count of printouts by id
   * @returns {Promise<number>}
   */
  static async getCount(protocolId: number): Promise<number> {
    return await dataSource
      .getRepository(protocolPrintout)
      .createQueryBuilder("protocolPrintout")
      .where("protocolPrintout.protocolId = :protocolId", { protocolId })
      .getCount()
      .then((res) => {
        return res;
      })
      .catch((err) => {
        throw new DatabaseActionException("SELECT", "protocolPrintout", err);
      });
  }
}
