import { dataSource } from "../../data-source";
import { executivePosition } from "../../entity/configuration/executivePosition";
import { memberExecutivePositions } from "../../entity/club/member/memberExecutivePositions";
import InternalException from "../../exceptions/internalException";
import DatabaseActionException from "../../exceptions/databaseActionException";

export default abstract class ExecutivePositionService {
  /**
   * @description get all executivePositions
   * @returns {Promise<Array<executivePosition>>}
   */
  static async getAll(): Promise<Array<executivePosition>> {
    return await dataSource
      .getRepository(executivePosition)
      .createQueryBuilder("executivePosition")
      .orderBy("executivePosition.position", "ASC")
      .getMany()
      .then((res) => {
        return res;
      })
      .catch((err) => {
        throw new DatabaseActionException("SELECT", "executivePosition", err);
      });
  }

  /**
   * @description get executivePosition by id
   * @returns {Promise<executivePosition>}
   */
  static async getById(id: number): Promise<executivePosition> {
    return await dataSource
      .getRepository(executivePosition)
      .createQueryBuilder("executivePosition")
      .where("executivePosition.id = :id", { id: id })
      .getOneOrFail()
      .then((res) => {
        return res;
      })
      .catch((err) => {
        throw new DatabaseActionException("SELECT", "executivePosition", err);
      });
  }
}
