import { dataSource } from "../../data-source";
import { membershipStatus } from "../../entity/configuration/membershipStatus";
import InternalException from "../../exceptions/internalException";
import { membership } from "../../entity/club/member/membership";
import DatabaseActionException from "../../exceptions/databaseActionException";

export default abstract class MembershipStatusService {
  /**
   * @description get all membershipStatuss
   * @returns {Promise<Array<membershipStatus>>}
   */
  static async getAll(): Promise<Array<membershipStatus>> {
    return await dataSource
      .getRepository(membershipStatus)
      .createQueryBuilder("membershipStatus")
      .orderBy("membershipStatus.status", "ASC")
      .getMany()
      .then((res) => {
        return res;
      })
      .catch((err) => {
        throw new DatabaseActionException("SELECT", "membershipStatus", err);
      });
  }

  /**
   * @description get membershipStatus by id
   * @returns {Promise<membershipStatus>}
   */
  static async getById(id: number): Promise<membershipStatus> {
    return await dataSource
      .getRepository(membershipStatus)
      .createQueryBuilder("membershipStatus")
      .where("membershipStatus.id = :id", { id: id })
      .getOneOrFail()
      .then((res) => {
        return res;
      })
      .catch((err) => {
        throw new DatabaseActionException("SELECT", "membershipStatus", err);
      });
  }
}
