import { dataSource } from "../../data-source";
import { newsletterConfig } from "../../entity/configuration/newsletterConfig";
import { member } from "../../entity/club/member/member";
import InternalException from "../../exceptions/internalException";
import DatabaseActionException from "../../exceptions/databaseActionException";

export default abstract class NewsletterConfigService {
  /**
   * @description get all newsletterConfigs
   * @returns {Promise<Array<newsletterConfig>>}
   */
  static async getAll(): Promise<Array<newsletterConfig>> {
    return await dataSource
      .getRepository(newsletterConfig)
      .createQueryBuilder("newsletterConfig")
      .leftJoinAndSelect("newsletterConfig.comType", "comType")
      .orderBy("comType.type", "ASC")
      .getMany()
      .then((res) => {
        return res;
      })
      .catch((err) => {
        throw new DatabaseActionException("SELECT", "newsletterConfig", err);
      });
  }

  /**
   * @description get newsletterConfig by id
   * @returns {Promise<newsletterConfig>}
   */
  static async getByComId(comId: number): Promise<newsletterConfig> {
    return await dataSource
      .getRepository(newsletterConfig)
      .createQueryBuilder("newsletterConfig")
      .leftJoinAndSelect("newsletterConfig.comType", "comType")
      .where("newsletterConfig.comTypId = :comTypId", { icomTypId: comId })
      .getOneOrFail()
      .then((res) => {
        return res;
      })
      .catch((err) => {
        throw new DatabaseActionException("SELECT", "newsletterConfig", err);
      });
  }
}
