import { dataSource } from "../../data-source";
import { invite } from "../../entity/management/invite";
import DatabaseActionException from "../../exceptions/databaseActionException";
import InternalException from "../../exceptions/internalException";

export default abstract class InviteService {
  /**
   * @description get all invites
   * @returns {Promise<Array<invite>>}
   */
  static async getAll(): Promise<Array<invite>> {
    return await dataSource
      .getRepository(invite)
      .createQueryBuilder("invite")
      .getMany()
      .then((res) => {
        return res;
      })
      .catch((err) => {
        throw new DatabaseActionException("SELECT", "invite", err);
      });
  }

  /**
   * @description get invite by id
   * @param mail string
   * @param token string
   * @returns {Promise<invite>}
   */
  static async getByMailAndToken(mail: string, token: string): Promise<invite> {
    return await dataSource
      .getRepository(invite)
      .createQueryBuilder("invite")
      .where("invite.mail = :mail", { mail: mail })
      .andWhere("invite.token = :token", { token: token })
      .getOneOrFail()
      .then((res) => {
        return res;
      })
      .catch((err) => {
        throw new DatabaseActionException("SELECT", "invite", err);
      });
  }
}
