import { dataSource } from "../../data-source";
import { userPermission } from "../../entity/management/user_permission";
import DatabaseActionException from "../../exceptions/databaseActionException";
import InternalException from "../../exceptions/internalException";

export default abstract class UserPermissionService {
  /**
   * @description get permission by user
   * @param userId string
   * @returns {Promise<Array<userPermission>>}
   */
  static async getByUser(userId: string): Promise<Array<userPermission>> {
    return await dataSource
      .getRepository(userPermission)
      .createQueryBuilder("permission")
      .where({ userId: userId })
      .getMany()
      .then((res) => {
        return res;
      })
      .catch((err) => {
        throw new DatabaseActionException("SELECT", "userPermission", err);
      });
  }
}
