import { dataSource } from "../../data-source";
import { webapiPermission } from "../../entity/management/webapi_permission";
import DatabaseActionException from "../../exceptions/databaseActionException";
import InternalException from "../../exceptions/internalException";

export default abstract class WebapiPermissionService {
  /**
   * @description get permission by api
   * @param webapiId number
   * @returns {Promise<Array<webapiPermission>>}
   */
  static async getByApi(webapiId: number): Promise<Array<webapiPermission>> {
    return await dataSource
      .getRepository(webapiPermission)
      .createQueryBuilder("webapi_permission")
      .where("webapi_permission.webapiId = :webapiId", { webapiId: webapiId })
      .getMany()
      .then((res) => {
        return res;
      })
      .catch((err) => {
        throw new DatabaseActionException("SELECT", "webapiPermission", err);
      });
  }
}
