import { Like, In } from "typeorm";
import { dataSource } from "../../../data-source";
import { equipmentType } from "../../../entity/unit/equipment/equipmentType";
import DatabaseActionException from "../../../exceptions/databaseActionException";

export default abstract class EquipmentTypeService {
  /**
   * @description get all equipmentTypes
   * @returns {Promise<[Array<equipmentType>, number]>}
   */
  static async getAll({
    offset = 0,
    count = 25,
    search = "",
    noLimit = false,
  }: {
    offset?: number;
    count?: number;
    search?: string;
    noLimit?: boolean;
  }): Promise<[Array<equipmentType>, number]> {
    let query = dataSource
      .getRepository(equipmentType)
      .createQueryBuilder("equipmentType")
      .loadRelationCountAndMap("equipmentType.equipmentCount", "equipmentType.equipment");

    if (search != "") {
      query = query.where({
        type: Like(`%${search}%`),
      });
    }

    if (!noLimit) {
      query = query.offset(offset).limit(count);
    }

    return await query
      .orderBy("type", "ASC")
      .getManyAndCount()
      .then((res) => {
        return res;
      })
      .catch((err) => {
        throw new DatabaseActionException("SELECT", "equipmentType", err);
      });
  }

  /**
   * @description get equipmentType by id
   * @returns {Promise<equipmentType>}
   */
  static async getById(id: string): Promise<equipmentType> {
    return await dataSource
      .getRepository(equipmentType)
      .createQueryBuilder("equipmentType")
      .where({ id })
      .getOneOrFail()
      .then((res) => {
        return res;
      })
      .catch((err) => {
        throw new DatabaseActionException("SELECT", "equipmentType", err);
      });
  }
}
