import { dataSource } from "../../../data-source";
import { inspectionPointResult } from "../../../entity/unit/inspection/inspectionPointResult";
import DatabaseActionException from "../../../exceptions/databaseActionException";

export default abstract class InspectionPointResultService {
  /**
   * @description get all inspectionPointResults
   * @returns {Promise<Array<inspectionPointResult>>}
   */
  static async getAllForInspection(inspectionId: string): Promise<Array<inspectionPointResult>> {
    return await dataSource
      .getRepository(inspectionPointResult)
      .createQueryBuilder("inspectionPointResult")
      .leftJoinAndSelect("inspectionPointResult.inspectionPoint", "inspectionPoint")
      .where({ inspectionId })
      .getMany()
      .then((res) => {
        return res;
      })
      .catch((err) => {
        throw new DatabaseActionException("SELECT", "inspectionPointResult", err);
      });
  }
  /**
   * @description get inspectionPointResults by inspection and point
   * @returns {Promise<Array<inspectionPointResult>>}
   */
  static async getForInspectionAndPoint(
    inspectionId: string,
    inspectionPointId: string
  ): Promise<inspectionPointResult> {
    return await dataSource
      .getRepository(inspectionPointResult)
      .createQueryBuilder("inspectionPointResult")
      .leftJoinAndSelect("inspectionPointResult.inspectionPoint", "inspectionPoint")
      .where({ inspectionId, inspectionPointId })
      .getOneOrFail()
      .then((res) => {
        return res;
      })
      .catch((err) => {
        throw new DatabaseActionException("SELECT", "inspectionPointResult", err);
      });
  }
}
