import { dataSource } from "../../../data-source";
import { inspectionPoint } from "../../../entity/unit/inspection/inspectionPoint";
import DatabaseActionException from "../../../exceptions/databaseActionException";

export default abstract class InspectionPointService {
  /**
   * @description get all inspectionPoints
   * @returns {Promise<Array<inspectionPoint>>}
   */
  static async getAllForVersionedPlan(versionedPlanId: string): Promise<Array<inspectionPoint>> {
    return await dataSource
      .getRepository(inspectionPoint)
      .createQueryBuilder("inspectionPoint")
      .where({ versionedPlanId })
      .orderBy("sort", "ASC")
      .getMany()
      .then((res) => {
        return res;
      })
      .catch((err) => {
        throw new DatabaseActionException("SELECT", "inspectionPoint", err);
      });
  }

  /**
   * @description get inspectionPoint by id
   * @returns {Promise<inspectionPoint>}
   */
  static async getById(id: string): Promise<inspectionPoint> {
    return await dataSource
      .getRepository(inspectionPoint)
      .createQueryBuilder("inspectionPoint")
      .where({ id })
      .getOneOrFail()
      .then((res) => {
        return res;
      })
      .catch((err) => {
        throw new DatabaseActionException("SELECT", "inspectionPoint", err);
      });
  }
}
