import { Like, In } from "typeorm";
import { dataSource } from "../../../data-source";
import { vehicleType } from "../../../entity/unit/vehicle/vehicleType";
import DatabaseActionException from "../../../exceptions/databaseActionException";

export default abstract class VehicleTypeService {
  /**
   * @description get all vehicleTypes
   * @returns {Promise<[Array<vehicleType>, number]>}
   */
  static async getAll({
    offset = 0,
    count = 25,
    search = "",
    noLimit = false,
  }: {
    offset?: number;
    count?: number;
    search?: string;
    noLimit?: boolean;
  }): Promise<[Array<vehicleType>, number]> {
    let query = dataSource
      .getRepository(vehicleType)
      .createQueryBuilder("vehicleType")
      .loadRelationCountAndMap("vehicleType.vehicleCount", "vehicleType.vehicle");

    if (search != "") {
      query = query.where({
        type: Like(`%${search}%`),
      });
    }

    if (!noLimit) {
      query = query.offset(offset).limit(count);
    }

    return await query
      .orderBy("type", "ASC")
      .getManyAndCount()
      .then((res) => {
        return res;
      })
      .catch((err) => {
        throw new DatabaseActionException("SELECT", "vehicleType", err);
      });
  }

  /**
   * @description get vehicleType by id
   * @returns {Promise<vehicleType>}
   */
  static async getById(id: string): Promise<vehicleType> {
    return await dataSource
      .getRepository(vehicleType)
      .createQueryBuilder("vehicleType")
      .where({ id })
      .getOneOrFail()
      .then((res) => {
        return res;
      })
      .catch((err) => {
        throw new DatabaseActionException("SELECT", "vehicleType", err);
      });
  }
}
