import { In, Like } from "typeorm";
import { dataSource } from "../../../data-source";
import { wearableType } from "../../../entity/unit/wearable/wearableType";
import DatabaseActionException from "../../../exceptions/databaseActionException";

export default abstract class WearableTypeService {
  /**
   * @description get all wearableTypes
   * @returns {Promise<[Array<wearableType>, number]>}
   */
  static async getAll({
    offset = 0,
    count = 25,
    search = "",
    noLimit = false,
  }: {
    offset?: number;
    count?: number;
    search?: string;
    noLimit?: boolean;
  }): Promise<[Array<wearableType>, number]> {
    let query = dataSource
      .getRepository(wearableType)
      .createQueryBuilder("wearableType")
      .loadRelationCountAndMap("wearableType.wearableCount", "wearableType.wearable");

    if (search != "") {
      query = query.where({
        type: Like(`%${search}%`),
      });
    }

    if (!noLimit) {
      query = query.offset(offset).limit(count);
    }

    return await query
      .orderBy("type", "ASC")
      .getManyAndCount()
      .then((res) => {
        return res;
      })
      .catch((err) => {
        throw new DatabaseActionException("SELECT", "wearableType", err);
      });
  }

  /**
   * @description get wearableType by id
   * @returns {Promise<wearableType>}
   */
  static async getById(id: string): Promise<wearableType> {
    return await dataSource
      .getRepository(wearableType)
      .createQueryBuilder("wearableType")
      .where({ id })
      .getOneOrFail()
      .then((res) => {
        return res;
      })
      .catch((err) => {
        throw new DatabaseActionException("SELECT", "wearableType", err);
      });
  }
}
