import { DataSource, ViewColumn, ViewEntity } from "typeorm";
import { memberExecutivePositions } from "../entity/club/member/memberExecutivePositions";

@ViewEntity({
  expression: (datasource: DataSource) =>
    datasource
      .getRepository(memberExecutivePositions)
      .createQueryBuilder("memberExecutivePositions")
      .select("executivePosition.id", "positionId")
      .addSelect("executivePosition.position", "position")
      .addSelect("member.id", "memberId")
      .addSelect("member.firstname", "memberFirstname")
      .addSelect("member.lastname", "memberLastname")
      .addSelect("member.nameaffix", "memberNameaffix")
      .addSelect("member.birthdate", "memberBirthdate")
      .addSelect("salutation.salutation", "memberSalutation")
      .addSelect(
        `SUM(COALESCE("memberExecutivePositions"."end", CURRENT_DATE) - "memberExecutivePositions"."start")`,
        "durationInDays"
      )
      .addSelect(
        `SUM(EXTRACT(YEAR FROM AGE(COALESCE("memberExecutivePositions"."end", CURRENT_DATE), "memberExecutivePositions"."start")))`,
        "durationInYears"
      )
      .addSelect(
        `SUM(AGE(COALESCE("memberExecutivePositions"."end", CURRENT_DATE), "memberExecutivePositions"."start"))`,
        "exactDuration"
      )
      .leftJoin("memberExecutivePositions.executivePosition", "executivePosition")
      .leftJoin("memberExecutivePositions.member", "member")
      .leftJoin("member.salutation", "salutation")
      .groupBy("executivePosition.id")
      .addGroupBy("member.id")
      .addGroupBy("salutation.id"),
})
export class memberExecutivePositionsView {
  @ViewColumn()
  durationInDays: number;

  @ViewColumn()
  durationInYears: number;

  @ViewColumn()
  exactDuration: string;

  @ViewColumn()
  position: string;

  @ViewColumn()
  positionId: number;

  @ViewColumn()
  memberId: string;

  @ViewColumn()
  memberSalutation: string;

  @ViewColumn()
  memberFirstname: string;

  @ViewColumn()
  memberLastname: string;

  @ViewColumn()
  memberNameaffix: string;

  @ViewColumn()
  memberBirthdate: Date;
}
