import { DataSource, ViewColumn, ViewEntity } from "typeorm";
import { memberQualifications } from "../entity/club/member/memberQualifications";

@ViewEntity({
  expression: (datasource: DataSource) =>
    datasource
      .getRepository(memberQualifications)
      .createQueryBuilder("memberQualifications")
      .select("qualification.id", "qualificationId")
      .addSelect("qualification.qualification", "qualification")
      .addSelect("member.id", "memberId")
      .addSelect("member.firstname", "memberFirstname")
      .addSelect("member.lastname", "memberLastname")
      .addSelect("member.nameaffix", "memberNameaffix")
      .addSelect("member.birthdate", "memberBirthdate")
      .addSelect("salutation.salutation", "memberSalutation")
      .addSelect(
        `SUM(COALESCE("memberQualifications"."end", CURRENT_DATE) - "memberQualifications"."start")`,
        "durationInDays"
      )
      .addSelect(
        `SUM(EXTRACT(YEAR FROM AGE(COALESCE("memberQualifications"."end", CURRENT_DATE), "memberQualifications"."start")))`,
        "durationInYears"
      )
      .addSelect(
        `SUM(AGE(COALESCE("memberQualifications"."end", CURRENT_DATE), "memberQualifications"."start"))`,
        "exactDuration"
      )
      .leftJoin("memberQualifications.qualification", "qualification")
      .leftJoin("memberQualifications.member", "member")
      .leftJoin("member.salutation", "salutation")
      .groupBy("qualification.id")
      .addGroupBy("member.id")
      .addGroupBy("salutation.id"),
})
export class memberQualificationsView {
  @ViewColumn()
  durationInDays: number;

  @ViewColumn()
  durationInYears: number;

  @ViewColumn()
  exactDuration: string;

  @ViewColumn()
  qualification: string;

  @ViewColumn()
  qualificationId: number;

  @ViewColumn()
  memberId: string;

  @ViewColumn()
  memberSalutation: string;

  @ViewColumn()
  memberFirstname: string;

  @ViewColumn()
  memberLastname: string;

  @ViewColumn()
  memberNameaffix: string;

  @ViewColumn()
  memberBirthdate: Date;
}
