import { Server, Socket } from "socket.io";
import { emitEvent, handleEvent } from "../handleEvent";
import { SocketConnectionTypes } from "../../enums/socketEnum";

export default (io: Server, socket: Socket) => {
  socket.on(
    "session:join",
    handleEvent(
      "noPermissionsRequired",
      async (room: string) => {
        const socketsInOtherRoom = await io.of(SocketConnectionTypes.scanner).in(room).fetchSockets();
        const count = socketsInOtherRoom.length;

        if (count == 0) {
          return {
            type: "status-session:join",
            answer: { status: "failed" },
          };
        } else {
          socket.join(room);
          emitEvent(
            {
              type: "package-scanner_join",
              answer: socket.id,
              room: room,
              namespace: SocketConnectionTypes.scanner,
            },
            socket,
            io
          );

          return {
            type: "status-session:join",
            answer: { status: "success" },
          };
        }
      },
      socket
    )
  );

  socket.on(
    "session:leave",
    handleEvent(
      "noPermissionsRequired",
      async () => {
        console.log("called leave");
        const rooms = Array.from(socket.rooms).filter((r) => r !== socket.id);
        const room = rooms[0];

        socket.leave(room);
        emitEvent(
          {
            type: "package-scanner_leave",
            answer: socket.id,
            room: room,
            namespace: SocketConnectionTypes.scanner,
          },
          socket,
          io
        );

        return {
          type: "status-session:leave",
          answer: { status: "success" },
        };
      },
      socket
    )
  );

  socket.on(
    "scan:send",
    handleEvent(
      "noPermissionsRequired",
      async (result: string) => {
        const rooms = Array.from(socket.rooms).filter((r) => r !== socket.id);
        const room = rooms[0];

        emitEvent(
          {
            type: "package-scan_receive",
            answer: result,
            room: room,
            namespace: SocketConnectionTypes.scanner,
          },
          socket,
          io
        );

        return {
          type: "status-scan:send",
          answer: { status: "success" },
        };
      },
      socket
    )
  );

  socket.on("disconnecting", () => {
    const rooms = Array.from(socket.rooms).filter((r) => r !== socket.id);
    const room = rooms[0];

    socket.leave(room);
    emitEvent(
      {
        type: "package-scanner_leave",
        answer: socket.id,
        room: room,
        namespace: SocketConnectionTypes.scanner,
      },
      socket,
      io
    );
  });
};
