import { Server, Socket } from "socket.io";
import { emitEvent, handleEvent } from "../handleEvent";
import { SocketConnectionTypes } from "../../enums/socketEnum";

export default (io: Server, socket: Socket) => {
  socket.on(
    "session:create",
    handleEvent(
      "noPermissionsRequired",
      async (room: string) => {
        socket.join(room);
        return {
          type: "status-session:create",
          answer: { status: "success" },
        };
      },
      socket
    )
  );

  socket.on(
    "session:close",
    handleEvent(
      "noPermissionsRequired",
      async () => {
        const rooms = Array.from(socket.rooms).filter((r) => r !== socket.id);
        const room = rooms[0];
        socket.leave(room);
        emitEvent(
          {
            type: "package-host_leave",
            answer: "host_leave",
            room: room,
            namespace: SocketConnectionTypes.pscanner,
          },
          socket,
          io
        );
        return {
          type: "status-session:close",
          answer: { status: "success" },
        };
      },
      socket
    )
  );

  socket.on("disconnecting", () => {
    const rooms = Array.from(socket.rooms).filter((r) => r !== socket.id);
    const room = rooms[0];
    // io.of(SocketConnectionTypes.pscanner).in(room).disconnectSockets();
    emitEvent(
      {
        type: "package-host_leave",
        answer: "host_leave",
        room: room,
        namespace: SocketConnectionTypes.pscanner,
      },
      socket,
      io
    );
  });
};
